$PROBLEM NIELSEN 2007 INVITRO AB PK/PD

$INPUT ID C TYPE EVID CMT TIME DV AMT L2 DIL

$DATA data_nielsen_2007.csv IGNORE=@

$SUBS  ADVAN9 TOL7

$MODEL
NCOMP=4
COMP=(S)    ;Bacteria in growth state (Sucseptible)
COMP=(R)    ;Bacteria in resting state (Resistant)
COMP=(ABS)  ;Total drug concentration
COMP=(PK)   ;Active drug concentration

$PK
" FIRST
"  COMMON /PRCOMG/ IDUM1,IDUM2,IMAX,IDUM4,IDUM5
"  INTEGER IDUM1,IDUM2,IMAX,IDUM4,IDUM5
"  IMAX=10000000

;Store the estimated subpopulation of the current individual in EST
EST=MIXEST

TVKGS   = THETA(1)
TVKK    = THETA(2)

IF(TYPE.EQ.2) TVEMAX  = THETA(3) ;PCG
IF(TYPE.EQ.3) TVEMAX  = THETA(4) ;ERYTRO
IF(TYPE.EQ.4) TVEMAX  = THETA(5) ;CEFUR
IF(TYPE.EQ.5) TVEMAX  = THETA(6) ;VANCO
IF(TYPE.EQ.6) TVEMAX  = THETA(7) ;MOXI

IF(TYPE.EQ.2) TVEC50  = THETA(8)*0.001  ;PCG
IF(TYPE.EQ.3) TVEC50  = THETA(9)*0.001  ;ERYTRO
IF(TYPE.EQ.4) TVEC50  = THETA(10)*0.001 ;CEFUR
IF(TYPE.EQ.5) TVEC50  = THETA(11)*0.001 ;VANCO
IF(TYPE.EQ.6) TVEC50  = THETA(12)*0.001 ;MOXI

IF(TYPE.EQ.2) TVGAM   = THETA(13) ;PCG
IF(TYPE.EQ.3) TVGAM   = THETA(14) ;ERYTRO
IF(TYPE.EQ.4) TVGAM   = THETA(15) ;CEFUR
IF(TYPE.EQ.5) TVGAM   = THETA(16) ;VANCO
IF(TYPE.EQ.6) TVGAM   = THETA(17) ;MOXI

IF(TYPE.EQ.2) TVKD  = THETA(22)  ;PCG
IF(TYPE.EQ.3) TVKD  = THETA(23)  ;ERYTRO
IF(TYPE.EQ.4) TVKD  = THETA(24)  ;CEFUR
IF(TYPE.EQ.5) TVKD  = THETA(25)  ;VANCO
IF(TYPE.EQ.6) TVKD  = THETA(26)  ;MOXI

IF(TYPE.EQ.2) TVKEO  = THETA(27) ;PCG
IF(TYPE.EQ.3) TVKEO  = THETA(28) ;ERYTRO
IF(TYPE.EQ.4) TVKEO  = THETA(29) ;CEFUR
IF(TYPE.EQ.5) TVKEO  = THETA(30) ;VANCO
IF(TYPE.EQ.6) TVKEO  = THETA(31) ;MOXI

TVBMAX  = THETA(18)*1000000

;PERS = Pre Existing Resistant, resting phase
;Estimate the fraction of bacteria in resting phase in the current mixture state
IF(MIXNUM.EQ.1) PERS=AMT*THETA(19) ;Log growth, no bacteria (0 FIX) in resting state at time=0
IF(MIXNUM.EQ.2) PERS=AMT*THETA(20) ;Stationary phase, estimate fraction of bacteria in resting state at time=0

;Set initial conditions
A_0(2)=PERS ;Bacteria in resting state
A_0(3)=C    ;Total drug concentration
A_0(4)=0    ;Active drug concentration

IF(MIXNUM.EQ.1) F1=(1-THETA(19))  ;Log growth, no bacteria (0 FIX) in resting state at time=0
IF(MIXNUM.EQ.2) F1=(1-THETA(20))  ;Stationary phase, estimate fraction of bacteria in resting state at time=0

KGS    = TVKGS*EXP(ETA(1))
KK     = TVKK
EMAX   = TVEMAX
EC50   = TVEC50
GAM    = TVGAM
BMAX   = TVBMAX
KD     = TVKD
KEO    = TVKEO

;Estimate the mixture probabillities of the experiment for the two subcategories; 1 Log growth, 2 Stationary phase
$MIX
P(1)=THETA(21)
P(2)=1.-THETA(21)
NSPOP=2

$DES

CABS=(A(3)) ;Total drug
IF(CABS.LT.0.001) CABS=0

CEFF=(A(4)) ;Active drug
IF(CEFF.LT.0.00001) CEFF=0

;Drug effect
DRUGS = EMAX*(CEFF)**GAM/(EC50**GAM+(CEFF)**GAM)

;Tranfer rate from growing to resting state
FEED=(KGS-KK)/BMAX

;Tranfer rate from growing to resting state scaled to the total number of bacteria
SR=FEED*((A(1))+(A(2)))

;Tranfer rate from resting to growing state is not experimentally observed
RS=0

;Differential equation system
DADT(1)=KGS*(A(1))-(KK+DRUGS)*(A(1)) - SR*(A(1)) + RS*(A(2)) ;Bacteria in growing state
DADT(2)=-KK*(A(2)) + SR*(A(1)) - RS*(A(2))                   ;Bacteria in resting state
DADT(3)=-KD*(A(3))                                           ;Total drug concentration
DADT(4)=KEO*(A(3))-KEO*(A(4))                                ;Active drug concentration

$ERROR
A1=(A(1))  ;Bacteria in growing state
A2=(A(2))  ;Bacteria in resting state
ATOT=A1+A2 ;Total number of bacteria
A3=(A(3))  ;Total drug concentration
A4=(A(4))  ;Active drug concentration

DEL=0
IF(F.EQ.0) DEL=1 ;Guard against log(0)

IPRED=LOG(ATOT+DEL)                ;Log transform data

IRES  = DV-IPRED                   ;Calculate residual

W=1                                ;Constant additative error
IWRES = IRES/W

IF(DIL.EQ.1) Y=IPRED+EPS(1)+EPS(2) ;Error replicate 1
IF(DIL.EQ.2) Y=IPRED+EPS(1)+EPS(3) ;Error replicate 2
IF(DIL.EQ.3) Y=IPRED+EPS(1)+EPS(4) ;Error replicate 3

$THETA  (0.5,1.35,5)  ; 1. KGS
$THETA  (0.05,0.18,1) ; 2. KK

$THETA  (0.5,2.4,5)   ; 3. EMAX PCG
$THETA  (0.5,2.1,5)   ; 4. EMAX ERYTRO
$THETA  (0.5,3.3,5)   ; 5. EMAX CEFUR
$THETA  (0.5,1.4,5)   ; 6. EMAX VANCO
$THETA  (0.5,3.2,5)   ; 7. EMAX MOXI

$THETA  (1,4.6,10)    ; 8. EC50 PCG
$THETA  (1,28,50)     ; 9. E5C0 ERYTRO
$THETA  (1,8.2,50)    ; 10. E5C0 CEFUR
$THETA  (1,384,400)   ; 11. E5C0 VANCO
$THETA  (1,75,200)    ; 12. E5C0 MOXI

$THETA  (0,1,5)       ; 13. GAM PCG
$THETA  (0,1,5)       ; 14. GAM ERYTRO
$THETA  (0,1,5)       ; 15. GAM CEFUR
$THETA  20 FIX        ; 16. GAM VANCO
$THETA  (0,1,5)       ; 17. GAM MOXI
 
$THETA  (300,420,600)      ; 18. BMAX
$THETA  0 FIX              ; 19. FRAKTION PERS 1
$THETA  (0.0001,0.05,0.99) ; 20. FRAKTION PERS 2
$THETA  (0.001,0.74,1)     ; 21. FRAKTION 1

;Drug degradation rates previosly determined
$THETA  0.020 FIX     ; 22. KD PCG
$THETA  0 FIX         ; 23. KD ERYTRO
$THETA  0.026 FIX     ; 24. KD CEFUR
$THETA  0 FIX         ; 25. KD VANCO
$THETA  0 FIX         ; 26. KD MOXI

$THETA  (0,1,100)     ; 27. KEO PCG
$THETA  100 FIX       ; 28. KEO ERYTRO
$THETA  (0,1,100)     ; 29. KEO CEFUR
$THETA  100 FIX       ; 30. KEO VANCO
$THETA  (0,1,100)     ; 31. KEO MOXI

;No IIV variabillity assumed
$OMEGA  0 FIX         ; ETA_EMAX

$SIGMA 0.98 ; Inter_replicate_error
$SIGMA BLOCK(1)
0.47 ; Intra_replicate_error_replicate_1
$SIGMA BLOCK(1) SAME
;; Intra_replicate_error_replicate_2
$SIGMA BLOCK(1) SAME
;; Intra_replicate_error_replicate_3

$EST METH=1 INTER SIGDIG=3  MAXEVAL=9999 POSTHOC  PRINT=1
$COV
$TABLE ID TYPE TIME C IPRED IWRES NOPRINT ONEHEADER FILE=sdtab_nielsen2007
$TABLE ATOT ID TYPE TIME C A3 A4 KGS SR RS BMAX EST KK EMAX EC50 GAM FEED IPRED NOPRINT ONEHEADER FILE=patab_nielsen2007
