;IGI for OGTT
;transit cmt absorption for oral glucose
;adapted for NM7.2
$PROBLEM FINAL IGI-OGTT
$INPUT ID TIME AMT ODV INSU TOTG CMT BW EVID RATE DV TYPE OCC
;data contains dosing records, glucose(1), hot glucose(3) and insulin(2)
$DATA data_OGTT.csv IGNORE=@
$SUBS ADVAN6 TRANS1 TOL=4

$MODEL
 COMP = GLU_C   ;1 central compartment glucose
 COMP = INS_C   ;2 central compartment insulin
 COMP = HOT_C   ;3 central compartment hot glucose
 COMP = GLU_P   ;4 peripheral compartment glucose     
 COMP = HOT_P   ;5 peripheral compartment hot glucose 
 COMP = GLU_INS ;6 effect compartment for glucose on insulin secr.
 COMP = INS_GLU ;7 effect compartment for insulin on glucose elim.

$PK 

DOSE = 75000
;--------------------parameters of residual error model------------------------
  RESG= THETA(17)                              ;proportional residual error glucose (IVGTT)
  RESI= THETA(18)                              ;proportional residual error insulin
  RESH= THETA(19)                              ;proportional residual error hot glucose (IVGTT)
  RESE= THETA(20)                              ;correction factor for early residual error (IVGTT)
  IF(OCC.EQ.1) RESG = THETA(21)                ;proportional residual error glucose (OGTT)
  IF(OCC.EQ.1) RESH = 1                        ;proportional residual error hot glucose (OGTT)
  IF(OCC.EQ.1) RESE = 1                        ;correction factor for early residual error (OGTT)
  GSCA = THETA(22)
  ISCA = THETA(23)

;----------------------parameters of the glucose distribution------------------
  IF(EVID.EQ.4) BASG=TOTG                      ;reset if event record is dosing with reset

  GSS = BASG*EXP(ETA(18)*RESG)*GSCA            ;baseline (mg/dL) (IVGTT)
  IF(OCC.EQ.1) GSS =BASG*EXP(ETA(19)*RESG)     ;baseline (mg/dL) (OGTT)
  BIOG= THETA(1)*EXP(ETA(1))                   ;biovailability
  MTT = THETA(2)*EXP(ETA(2))                   ;mean absorption transit time (min)
  N   = THETA(3)*EXP(ETA(3))                   ;number of transit compartments 
  CLG = THETA(4)*EXP(ETA(4))                   ;insulin-independent elimination (L/min)
  CLGI= THETA(5)*EXP(ETA(5))                   ;insulin-dependent elimination (L/min mU/L)(IVGTT)
  IF(OCC.EQ.1) CLGI=THETA(6)*EXP(ETA(6))       ;insulin-dependent elimination (L/min mU/L)(OGTT) 
  VP  = THETA(7)*EXP(ETA(7)+ETA(17))           ;peripheral volume (L) (OGTT)
  IF(OCC.EQ.1) VP  = THETA(7)*EXP(ETA(7)-ETA(17));peripheral volume (L) (IVGTT) 
  VG  = THETA(8)*EXP(ETA(8))*BW/70             ;central volume (L)
  Q   = THETA(9)*EXP(ETA(9))                   ;inter-comparment flow central-peripheral (L/min)

  K15 = Q/VG                                   ;rate constant from central to peripheral
  K51 = Q/VP                                   ;rate constant from peripheral to central
  KG  = CLG/VG                                 ;rate constant for insulin-indep. elimination
  KGI = CLGI/VG                                ;rate constant for insulin-dep.elimination
  IF(OCC.EQ.1) KCA=N/MTT                       ;rate constant for absorption transition
  
;----------------------parameters of the insulin distribution------------------
  IF(EVID.EQ.4) BASI=INSU                      ;if event record is dosing with reset

  ISS = BASI*EXP(ETA(20)*RESI)*ISCA            ;baseline (mU/L) (IVGTT)
  IF(OCC.EQ.1) ISS=BASI*EXP(ETA(21)*RESI)      ;baseline (mU/L) (OGTT)
  CLI = THETA(10)*EXP(ETA(10))                 ;elimination (L/min)
  VI  = THETA(11)*EXP(ETA(11))*BW/70           ;central volume (L)

  KI  = CLI/VI                                 ;rate constant for elimination

;----------------------parameters of feed-back interactions------------------
  KGE   = THETA(12)*EXP(ETA(12))               ;rate constant for glucose effect site delay 
  KIE   = THETA(13)*EXP(ETA(13))               ;rate constant for insulin effect site delay
  IPRG  = THETA(14)*EXP(ETA(14))               ;glucose on insulin secretion
  EMAX  = THETA(15)*EXP(ETA(15))               ;incretin max effect related to rate of absorption
  ABG5  = THETA(16)*EXP(ETA(16))               ;rate of abs. that gives 50% of EMAX

                                                                                                                                           
;-----initialization condictions and scalings---------------------------------
  F1 = 1/10                                    ;correction for glucose in mg/dL
  F3 = 0.26/10                                 ;correction for hot glucose
  A_0(1) = GSS*VG                              ;glcuose baselin
  A_0(2) = ISS*VI                              ;insulin baseline 
  A_0(3) = 0                                   ;hot glucose baseline
  A_0(4) = K15*GSS*VG/K51                      ;glucose peripheral compartment
  A_0(5) = 0                                   ;hot glucose peripheral compartment
  A_0(6) = GSS                                 ;glucose effect on insulin secr.
  A_0(7) = ISS                                 ;insulin effect on glucose elim.

$DES
;----------------------glucose------------------------------------------------
 GPR0 = GSS*(KG + KGI*ISS)*VG                  ;baseline production of glucose
 GPRO = GPR0                                   ;production of glucose
 GDIS = K15*A(1) - K51*A(4)                    ;distribution of glucose
 GELI = (KG + KGI*A(7))*A(1)                   ;elimination of glucose
 P1   = (N + 0.5)*LOG(N)
 P2   = LOG(1 + 1/(12*N))
 LNFAC= 0.9189385 + P1 - N + P2                ;n! - sterling's formula
 P3   = LOG(DOSE*(BIOG/10))
 P4   = N*LOG(KCA*T + 1E-6) 
 ABSG = KCA*EXP(P3+P4-KCA*T-LNFAC)             ;rate of glucose absorption (OGTT)
 IF(OCC.NE.1) ABSG = 0                         ;rate of glucose absorption (IVGTT)

;----------------hot glucose--------------------------------------------------
 HDIS = K15*A(3) - K51*A(5)                    ;distribution of hot glucose
 HELI = (KG + KGI*A(7))*A(3)                   ;elimination of hot glucose 

;------------------insulin----------------------------------------------------
 GCM2  = (A(6)/GSS+1E-6)**IPRG                 ;glucose on insulin secretion
 ISC0  = ISS*(KI)*VI                           ;baseline secretion of insulin
 IABG  = 1                                     ;incretin effect on insulin secr. (IVGTT)
 IF(OCC.EQ.1) IABG = 1+ABSG*EMAX/(ABSG+ABG5)   ;incretin effect on insulin secr. (OGTT)   
 ISEC  = ISC0*GCM2*IABG                        ;secretion of insulin
 IELI  =  KI*A(2)                              ;elimination of insulin

;----------------differential equations----------------------------------------
 DADT(1) = ABSG + GPRO - GELI - GDIS           ;glucose central
 DADT(2) = ISEC - IELI                         ;insulin central
 DADT(3) = - HELI - HDIS                       ;hot glucose central
 DADT(4) = GDIS                                ;glucose peripheral
 DADT(5) = HDIS                                ;hot glucose peripheral
 DADT(6) = KGE*(A(1)/VG - A(6))                ;glucose effect delay on insulin secr
 DADT(7) = KIE*(A(2)/VI - A(7))                ;insulin effect delay on glucose elim.

$ERROR
 GLUC = A(1)/VG
 INSC = A(2)/VI
 HOTC = A(3)/VG
 GLUP = A(4)
 HOTP = A(5)
 GLUE = A(6)
 INSE = A(7)
       
;---------------defining individual predictions--------------------------------
 IF (CMT.EQ.1) IPRED = GLUC+1E-6
 IF (CMT.EQ.2) IPRED = INSC+1E-6
 IF (CMT.EQ.3) IPRED = HOTC+1E-6
 IF (CMT.GE.4) IPRED = 1

;--------------defining error structures---------------------------------------
 IF (CMT.EQ.1) W = RESG
 IF (CMT.EQ.2) W = RESI
 IF (CMT.EQ.3) W = RESH
 IF (CMT.GE.4) W = 1
 IF(TIME.LE.2) W = W*RESE

 IRES  = DV-LOG(IPRED)
 IWRES = IRES/W
 Y = LOG(IPRED)+ERR(1)*W

;-----------initial estimates of fixed effects----------------------------------
$THETA (0, .811, 1)         ;1  BIOG
$THETA (0, 34.9)            ;2  MTT
$THETA (0, 1.27)            ;3  N
$THETA .0287  FIX           ;4  CLG_FIX
$THETA .00297 FIX           ;5  CLGI_FIX
$THETA (0, .00590)          ;6  CLGI_PO
$THETA 8.56   FIX           ;7  VP_FIX
$THETA 9.33   FIX           ;8  VG_FIX
$THETA .442   FIX           ;9  Q_FIX
$THETA 6.09   FIX           ;10 VI_FIX
$THETA 1.22   FIX           ;11 CLI_FIX
$THETA .0289  FIX           ;12 KGE_FIX
$THETA .0213  FIX           ;13 KIE_FIX
$THETA 1.42   FIX           ;14 IPRG_FIX
$THETA (0, 1.47)            ;15 EMAX
$THETA (0, 14.8)            ;16 ABSG50
$THETA .0436  FIX           ;17 RESG_FIX
$THETA .252   FIX           ;18 RESI_FIX
$THETA .0512  FIX           ;19 RESH_FIX
$THETA 3.31   FIX           ;20 RESE_FIX
$THETA (0, .0732)           ;21 RESG_PO
$THETA .891   FIX           ;22 SCALE_GSS_IV_FIX
$THETA .93    FIX           ;23 SCALE_ISS_IV_FIX
;-------------initial estimates of random effects representing IIV----------------
$OMEGA 0      FIX           ;1  BIOG_FIX 
$OMEGA .0117                ;2  MTT
$OMEGA 0      FIX           ;3  N_FIX
$OMEGA .352   FIX           ;4  CLG_FIX
$OMEGA BLOCK(2)
.227                        ;5  CLGI
.169 .207                   ;6  CLGI_PO
$OMEGA .0891  FIX           ;7  VP_FIX
$OMEGA BLOCK(3) FIX
.0887                       ;8  VG_FIX
-0.192 .73                  ;9  Q_FIX
.0855 -0.12 .165            ;10 VI_FIX
$OMEGA .0852  FIX           ;11 CLI_FIX
$OMEGA .728   FIX           ;12 KGE_FIX 
$OMEGA .337   FIX           ;13 KIE_FIX
$OMEGA 0   FIX           ;14 IPRG_FIX
$OMEGA .295                 ;15 EMAX
$OMEGA 1.26                 ;16 ABSG50
$OMEGA BLOCK(1).0238        ;17 VP_IOV
$OMEGA 1      FIX           ;18 GSS_IV_FIX
$OMEGA 1      FIX           ;19 GSS_PO_FIX
$OMEGA 1      FIX           ;20 ISS_IV_FIX
$OMEGA 1      FIX           ;21 ISS_PO_FIX
;--------------fixed residual error distibution-----------------------------------
$SIGMA 1      FIX           ;~RES_FIX

$EST MAXEVAL=9999 PRINT=1 POSTHOC MSFO=MSFB1 METH=1 NOABORT SIGDIG=2
;     NSIG=2 SIGL=6 ATOL=6
$COVARIANCE PRINT=E UNCOND

$TABLE ID TIME TYPE IPRED ODV GLUC INSC HOTC GLUE GLUP HOTP INSE CMT 
       NOPRINT ONEHEAD FILE=mytab1
$TABLE ID TIME DV IPRED  ODV GLUC INSC HOTC
       NOPRINT ONEHEAD FILE=mytab1
$TABLE ID TIME IPRED IWRES CMT TYPE 
       NOPRINT ONEHEAD FILE=sdtab1
$TABLE ID ETA2  ETA4  ETA5  ETA6  ETA8  ETA9 ETA10 
       ETA11 ETA12 ETA13 ETA15 ETA16 ETA7 ETA17 
       NOPRINT ONEHEAD FILE=patab1
