$PROB TUMOUR EXPOSURE
; THAM LS, WANG L, SOO RA, LEE SC, LEE HS, YONG WP, GOH BC, HOLFORD NH. 
; A PHARMACODYNAMIC MODEL FOR THE TIME COURSE OF TUMOR SHRINKAGE BY GEMCITABINE +
; CARBOPLATIN IN NON-SMALL CELL LUNG CANCER PATIENTS. 
; CLIN CANCER RES 2008; 14: 4213-8.
$INPUT ID TIME AMT DV
$DATA ..\tumour_exposure.csv

$EST MAX=9990 NSIG=3 SIGL=9 NOABORT PRINT=1
METHOD=CONDITIONAL INTERACTION
MSFO=tumour_size.msf
$COV

$THETA
(1,6.66,10) ; POP_SIZE0 CM
(1,18.9,200) ; POP_TOVER WEEK
(1,11700.,100000) ; POP_AE50 MG 
(1,8.27,100000) ; POP_TEQ WEEK

$OMEGA
0.317 ; PPV_SIZE0
0.082 ; PPV_TOVER
1.9 ; PPV_AE50

$SIGMA 
0.0358 ; RUV_CV
0.0125 ; RUV_SD CM^2

$SUBR ADVAN13 TOL=9
$MODEL
   COMP=DRUG
   COMP=TUMOUR

$PK

   GSIZE0=THETA(1)
   SIZE0=GSIZE0*EXP(ETA(1))
   GTOVER=THETA(2)*168 ; WEEK -> H
   TOVER=GTOVER*EXP(ETA(2))
   
   ; GEMCITABINE AMT IN DATA IS UMOLE (263G/MOLE)
   GAE50=THETA(3)/263*1000 ; MG -> UMOLE
   AE50=GAE50*EXP(ETA(3))
   ; TIME IN DATA IS HOURS
   GTEQ=THETA(4)*168 ; WEEK -> H
   TEQ=GTEQ

   KOVER=1/TOVER
   A_0(2)=SIZE0
   RIN=SIZE0*KOVER

   KPD=LOG(2)/TEQ
   S1=1

$DES
   ; STATE VARIABLES FOR DE SOLVER
   DAE=A(1) ; AMOUNT IN EFFECT COMPARTMENT
   DSIZE=A(2) ; TUMOUR SIZE
   PD=1 - DAE/(AE50+DAE) ; EMAX PHARMACODYNAMIC MODEL
   DADT(1) = -KPD*A(1) ; BOLUS DOSE (IN DATA) ENTERS IMPLICITLY
   DADT(2) = (RIN*PD - DSIZE*KOVER)*DSIZE

$ERROR

   ; STATE VARIABLE SOLUTION
   AE=A(1) ; AMOUNT IN EFFECT COMPARTMENT
   SIZE=A(2) ; TUMOUR SIZE

   Y=SIZE*(1 + ERR(1)) + ERR(2)

;$TABLE ID TIME AMT CMT DV MDV DVID DOSE 
;AUCG AUCI AUCE TK0 SEX AGE RACE KPS STGE
;NOAPPEND
;ONEHEADER NOPRINT FILE=SIZE.FIT


