$SIZES NO=500
$PROB SIMULATE TIME TO EVENT
$DATA data.csv
$INPUT ID TIME TRT AMT RATE ADDL II WT DVID DV MDV
$SIM (20091202) (20091203 UNIFORM) (20091204 UNIFORM)
(20091218 UNIFORM) (20091220 UNIFORM) NSUB=1

;O'Reilly RA, Aggeler PM. Studies on coumarin anticoagulant drugs
;Initiation of warfarin therapy without a loading dose.
;Circulation 1968;38:169-177
;
;O'Reilly RA, Aggeler PM, Leong LS. Studies of the coumarin anticoagulant
;drugs: The pharmacodynamics of warfarin in man.
;Journal of Clinical Investigation 1963;42(10):1542-1551

;Event hazard
$THETA
0.1 ; POP_HBASE 1/y baseline hazard (major haemorrhage)
0.2 ; POP_HDROP 1/y baseline hazard (dropout)
0 FIX ; POP_BTATRT hazard ratio increase per 1 mg/d warfarin (0.4)
0 FIX ; POP_BTAPCA hazard ratio increase with decrease in PCA (1.95)
0.48 ; POP_BTAINR hazard ratio increase with INR (0.48)

;Warfarin PKPD
$THETA
(0.01,0.128,1) ; POP_CL L/h/70kg
(0.01,8.11,20) ; POP_V L/70kg
(0.01,1.46,24) ; POP_TABS h
(0.,0.998,24) ; POP_LAG h
(0.01,96.3,200) ; POP_PCA0
-1. FIX ; POP_EMAX
(0.01,1.24,10) ; POP_C50 mg/L
(0.01,12.9,100) ; POP_TEQ h

$OMEGA
0.0645 ; PPV_CL
0.0183 ; PPV_V
0.619 ; PPV_TABS
0.278 ; PPV_LAG
0.001 ; PPV_PCA0
0 FIX ; PPV_EMAX
0.191 ; PPV_C50
0.0116 ; PPV_TEQ
0.01   ; PPV_HBASE

$SIGMA
0.00693 ; RUV_CV
0.0818 ; RUV_SD mg/L
16. ; RUV_PCA 

$THETA
70 ; WT_STD
$OMEGA
0.01 FIX ; PPV_WT

$SUBR ADVAN6 TOL=3
$MODEL
   COMP=CENTRAL
   COMP=PCA
   COMP=HAZEVT
   COMP=HAZDRP
$PK

   IF (NEWIND.LE.1) THEN
      LN2=LOG(2)
      HASEVT=0 ; not had event
      HASDRP=0 ; not dropped out
      SEVTZ=1 ; Survivor function at TIME=0      
   ENDIF
   IF (ICALL.EQ.4) THEN
      IF (NEWIND.LE.1) THEN ; first record
         CALL RANDOM(2,R)
         UEVT=R ; Uniform random number for event
         CALL RANDOM(3,R)
         UTRT=R ; Uniform random number for treatment
         CALL RANDOM(4,R)
         UDRP=R ; Uniform random number for dropout
         IF (UTRT.LT.0.25) THEN ; placebo
            RATE=0
            ADDL=0
            II=0
            AMT=0
         ELSE
; RATE, ADDL and II are pre-specified in input data
;            RATE=-2
;            ADDL=119 ; days
;            II=1 ; day
            IF (UTRT.LT.0.5) THEN ; dose 1
               AMT=2.5 ; mg
            ELSE
               IF (UTRT.LT.0.75) THEN ; dose 2
                  AMT=5 ; mg
               ELSE
                  AMT=10 ;mg
               ENDIF
            ENDIF
         ENDIF
         SWT=THETA(14)*EXP(ETA(10)) ; simulated weight
         STRT=AMT ; simulated treatment
      ELSE ; after first record
         RATE=0
         ADDL=0
         II=0
         AMT=0
      ENDIF
      WT=SWT
      TRT=STRT
   ENDIF
   FSZV=WT/70
   FSZCL=FSZV**0.75

   CL=FSZCL*THETA(6)*EXP(ETA(1))*24 ; L/h -> L/d
   V=FSZV*THETA(7)*EXP(ETA(2))
   TABS=THETA(8)*EXP(ETA(3))/24 ; h -> d
   TLAG=THETA(9)*EXP(ETA(4))/24 ; h -> d

   PCA0=THETA(10)*EXP(ETA(5))
   EMAX=THETA(11)*EXP(ETA(6))
   C50=THETA(12)*EXP(ETA(7))
   TEQ=THETA(13)*EXP(ETA(8))/24 ; h -> d

   HBASE=THETA(1)*EXP(ETA(9))/365 ; 1/y -> 1/d
   HDROP=THETA(2)/365 ; 1/y -> 1/d
   BTATRT=THETA(3) 
   BTAPCA=THETA(4) 
   BTAINR=THETA(5) 

   D1=TABS
   ALAG1=TLAG
   S1=V
   A_0(2)=PCA0
   KPCA=LN2/TEQ
   RPCA=PCA0*KPCA
   
$DES
   DCP=A(1)/V
   DPCA=A(2)
   DINR=PCA0/DPCA
   PD=1+EMAX*DCP/(C50+DCP)

   DADT(1)= - CL*DCP ; warfarin conc
   DADT(2)=RPCA*PD - KPCA*DPCA ; turnover for PCA
   DADT(3)=HBASE *(1+BTATRT*TRT) *EXP(BTAINR*DINR) *EXP(BTAPCA*(1-DPCA/PCA0))
   DADT(4)=HDROP

$ERROR

   CP=A(1)/V
   PCA=A(2)
   CUMEVT=A(3)
   CUMDRP=A(4)

   ; Prob of not having event up to this time
   SEVTT=EXP(-CUMEVT) ; Survivor function (t)

   ; Prob of not having dropped out to this time
   SDRPT=EXP(-CUMDRP) ; Survivor function (t)

   IF (DVID.LE.1) THEN
      F_FLAG=0
      Y=CP*(1+ERR(1)) + ERR(2)
   ENDIF
   IF (DVID.EQ.2) THEN
      F_FLAG=0
      Y=PCA + ERR(3)
   ENDIF
   IF (DVID.EQ.3.AND.DV.EQ.0) THEN ; Censored event
      F_FLAG=1
      Y=SEVTT ; Survivor function
   ENDIF
   IF (DVID.EQ.3.AND.DV.EQ.1) THEN ; Event in interval
      F_FLAG=1
      Y=SEVTZ - SEVTT ; likelihood of event in interval
   ENDIF

   IF (ICALL.EQ.4) THEN
      IF (DVID.EQ.3.AND.HASDRP.EQ.0.AND.SDRPT.LT.UDRP) THEN
         HASDRP=1
         DVX=0 ; censored event
         DVIX=3
         MDVX=0
      ELSE
         IF (HASDRP.EQ.0.AND.HASEVT.EQ.0) THEN
            IF (DVID.EQ.3) THEN ; check for event
               IF (SEVTT.LT.UEVT) THEN ; event 
                  HASEVT=1
                  DVX=1
                  DVIX=3
                  MDVX=0
               ELSE ; dummy event record
                  DVX=0
                  DVIX=3
                  MDVX=1
               ENDIF
            ELSE ; Last record (default for censoring) or other EVID (dose, obs)
               IF (DVID.EQ.4) THEN ; last record
                  DVX=0 ; censored event
                  DVIX=3
                  MDVX=0
               ELSE ; dose or conc or PCA
                  IF (DVID.EQ.0) THEN ; dose
                     DVX=0
                     MDVX=1
                  ELSE ; Observation
                     DVX=Y
                     MDVX=0
                  ENDIF
                  DVIX=DVID
               ENDIF
            ENDIF
         ELSE ; after dropout or after event so convert to missing
            DVX=0
            DVIX=DVID
            MDVX=1
         ENDIF
      ENDIF
   ENDIF

   IF (DVID.EQ.3) THEN ; start new event interval
      SEVTZ=SEVTT ; survivor function at start of new interval
   ELSE ; save recursive random variable (only works with NMVI)
      SEVTZ=SEVTZ
   ENDIF

   INR=PCA0/PCA

$TABLE ID TIME TRT AMT RATE ADDL II WT DVIX DVX MDVX CP PCA INR
NOAPPEND ONEHEADER NOPRINT FILE=warf_sim.fit
