$SIZES NO=500
$PROB SIMULATE TIME TO EVENT
$DATA ..\data.csv
$INPUT ID TIME TRT AMT RATE ADDL II WT DVID DV MDV
$SIM (20091202) (20091203 UNIFORM) (20091204 UNIFORM)
(20091218 UNIFORM) (20091220 UNIFORM) NSUB=1

;O'REILLY RA, AGGELER PM. STUDIES ON COUMARIN ANTICOAGULANT DRUGS
;INITIATION OF WARFARIN THERAPY WITHOUT A LOADING DOSE.
;CIRCULATION 1968;38:169-177
;
;O'REILLY RA, AGGELER PM, LEONG LS. STUDIES OF THE COUMARIN ANTICOAGULANT
;DRUGS: THE PHARMACODYNAMICS OF WARFARIN IN MAN.
;JOURNAL OF CLINICAL INVESTIGATION 1963;42(10):1542-1551

;EVENT HAZARD
$THETA
0.1 ; POP_HBASE 1/Y BASELINE HAZARD (MAJOR HAEMORRHAGE)
0.2 ; POP_HDROP 1/Y BASELINE HAZARD (DROPOUT)
0 FIX ; POP_BTATRT HAZARD RATIO INCREASE PER 1 MG/D WARFARIN (0.4)
0 FIX ; POP_BTAPCA HAZARD RATIO INCREASE WITH DECREASE IN PCA (1.95)
0.48 ; POP_BTAINR HAZARD RATIO INCREASE WITH INR (0.48)

;WARFARIN PKPD
$THETA
(0.01,0.128,1) ; POP_CL L/H/70KG
(0.01,8.11,20) ; POP_V L/70KG
(0.01,1.46,24) ; POP_TABS H
(0.,0.998,24) ; POP_LAG H
(0.01,96.3,200) ; POP_PCA0
-1. FIX ; POP_EMAX
(0.01,1.24,10) ; POP_C50 MG/L
(0.01,12.9,100) ; POP_TEQ H

$OMEGA
0.0645 ; PPV_CL
0.0183 ; PPV_V
0.619 ; PPV_TABS
0.278 ; PPV_LAG
0.001 ; PPV_PCA0
0 FIX ; PPV_EMAX
0.191 ; PPV_C50
0.0116 ; PPV_TEQ
0.01   ; PPV_HBASE

$SIGMA
0.00693 ; RUV_CV
0.0818 ; RUV_SD MG/L
16. ; RUV_PCA 

$THETA
70 ; WT_STD
$OMEGA
0.01 FIX ; PPV_WT

$SUBR ADVAN6 TOL=3
$MODEL
   COMP=CENTRAL
   COMP=PCA
   COMP=HAZEVT
   COMP=HAZDRP
$PK

   IF (NEWIND.LE.1) THEN
      LN2=LOG(2)
      HASEVT=0 ; NOT HAD EVENT
      HASDRP=0 ; NOT DROPPED OUT
      SEVTZ=1 ; SURVIVOR FUNCTION AT TIME=0      
   ENDIF
   IF (ICALL.EQ.4) THEN
      IF (NEWIND.LE.1) THEN ; FIRST RECORD
         CALL RANDOM(2,R)
         UEVT=R ; UNIFORM RANDOM NUMBER FOR EVENT
         CALL RANDOM(3,R)
         UTRT=R ; UNIFORM RANDOM NUMBER FOR TREATMENT
         CALL RANDOM(4,R)
         UDRP=R ; UNIFORM RANDOM NUMBER FOR DROPOUT
         IF (UTRT.LT.0.25) THEN ; PLACEBO
            RATE=0
            ADDL=0
            II=0
            AMT=0
         ELSE
; RATE, ADDL AND II ARE PRE-SPECIFIED IN INPUT DATA
;            RATE=-2
;            ADDL=119 ; DAYS
;            II=1 ; DAY
            IF (UTRT.LT.0.5) THEN ; DOSE 1
               AMT=2.5 ; MG
            ELSE
               IF (UTRT.LT.0.75) THEN ; DOSE 2
                  AMT=5 ; MG
               ELSE
                  AMT=10 ;MG
               ENDIF
            ENDIF
         ENDIF
         SWT=THETA(14)*EXP(ETA(10)) ; SIMULATED WEIGHT
         STRT=AMT ; SIMULATED TREATMENT
      ELSE ; AFTER FIRST RECORD
         RATE=0
         ADDL=0
         II=0
         AMT=0
      ENDIF
      WT=SWT
      TRT=STRT
   ENDIF
   FSZV=WT/70
   FSZCL=FSZV**0.75

   CL=FSZCL*THETA(6)*EXP(ETA(1))*24 ; L/H -> L/D
   V=FSZV*THETA(7)*EXP(ETA(2))
   TABS=THETA(8)*EXP(ETA(3))/24 ; H -> D
   TLAG=THETA(9)*EXP(ETA(4))/24 ; H -> D

   PCA0=THETA(10)*EXP(ETA(5))
   EMAX=THETA(11)*EXP(ETA(6))
   C50=THETA(12)*EXP(ETA(7))
   TEQ=THETA(13)*EXP(ETA(8))/24 ; H -> D

   HBASE=THETA(1)*EXP(ETA(9))/365 ; 1/Y -> 1/D
   HDROP=THETA(2)/365 ; 1/Y -> 1/D
   BTATRT=THETA(3) 
   BTAPCA=THETA(4) 
   BTAINR=THETA(5) 

   D1=TABS
   ALAG1=TLAG
   S1=V
   A_0(2)=PCA0
   KPCA=LN2/TEQ
   RPCA=PCA0*KPCA
   
$DES
   DCP=A(1)/V
   DPCA=A(2)
   DINR=PCA0/DPCA
   PD=1+EMAX*DCP/(C50+DCP)

   DADT(1)= - CL*DCP ; WARFARIN CONC
   DADT(2)=RPCA*PD - KPCA*DPCA ; TURNOVER FOR PCA
   DADT(3)=HBASE *(1+BTATRT*TRT) *EXP(BTAINR*DINR) *EXP(BTAPCA*(1-DPCA/PCA0))
   DADT(4)=HDROP

$ERROR

   CP=A(1)/V
   PCA=A(2)
   CUMEVT=A(3)
   CUMDRP=A(4)

   ; PROB OF NOT HAVING EVENT UP TO THIS TIME
   SEVTT=EXP(-CUMEVT) ; SURVIVOR FUNCTION (T)

   ; PROB OF NOT HAVING DROPPED OUT TO THIS TIME
   SDRPT=EXP(-CUMDRP) ; SURVIVOR FUNCTION (T)

   IF (DVID.LE.1) THEN
      F_FLAG=0
      Y=CP*(1+ERR(1)) + ERR(2)
   ENDIF
   IF (DVID.EQ.2) THEN
      F_FLAG=0
      Y=PCA + ERR(3)
   ENDIF
   IF (DVID.EQ.3.AND.DV.EQ.0) THEN ; CENSORED EVENT
      F_FLAG=1
      Y=SEVTT ; SURVIVOR FUNCTION
   ENDIF
   IF (DVID.EQ.3.AND.DV.EQ.1) THEN ; EVENT IN INTERVAL
      F_FLAG=1
      Y=SEVTZ - SEVTT ; LIKELIHOOD OF EVENT IN INTERVAL
   ENDIF

   IF (ICALL.EQ.4) THEN
      IF (DVID.EQ.3.AND.HASDRP.EQ.0.AND.SDRPT.LT.UDRP) THEN
         HASDRP=1
         DVX=0 ; CENSORED EVENT
         DVIX=3
         MDVX=0
      ELSE
         IF (HASDRP.EQ.0.AND.HASEVT.EQ.0) THEN
            IF (DVID.EQ.3) THEN ; CHECK FOR EVENT
               IF (SEVTT.LT.UEVT) THEN ; EVENT 
                  HASEVT=1
                  DVX=1
                  DVIX=3
                  MDVX=0
               ELSE ; DUMMY EVENT RECORD
                  DVX=0
                  DVIX=3
                  MDVX=1
               ENDIF
            ELSE ; LAST RECORD (DEFAULT FOR CENSORING) OR OTHER EVID (DOSE, OBS)
               IF (DVID.EQ.4) THEN ; LAST RECORD
                  DVX=0 ; CENSORED EVENT
                  DVIX=3
                  MDVX=0
               ELSE ; DOSE OR CONC OR PCA
                  IF (DVID.EQ.0) THEN ; DOSE
                     DVX=0
                     MDVX=1
                  ELSE ; OBSERVATION
                     DVX=Y
                     MDVX=0
                  ENDIF
                  DVIX=DVID
               ENDIF
            ENDIF
         ELSE ; AFTER DROPOUT OR AFTER EVENT SO CONVERT TO MISSING
            DVX=0
            DVIX=DVID
            MDVX=1
         ENDIF
      ENDIF
   ENDIF

   IF (DVID.EQ.3) THEN ; START NEW EVENT INTERVAL
      SEVTZ=SEVTT ; SURVIVOR FUNCTION AT START OF NEW INTERVAL
   ELSE ; SAVE RECURSIVE RANDOM VARIABLE (ONLY WORKS WITH NMVI)
      SEVTZ=SEVTZ
   ENDIF

   INR=PCA0/PCA

$TABLE ID TIME TRT AMT RATE ADDL II WT DVIX DVX MDVX CP PCA INR
NOAPPEND ONEHEADER NOPRINT FILE=warfarin_t2e_inr_sim.fit
