$PROB  FINAL FPG-HbA1c with PK of tesaglitasar
$INPUT ID TIME AMT RATE CMT CLI VI DOSE SEX EVID PRET ORIG DV
$DATA  data.csv IGNORE=@
$ABB   DERIV2=NO
$SUBS  ADVAN6 TOL=7

;-----Comments on data----------------------
;ID    - individual no
;TIME  - time in hours
;AMT   - amount of glucose ingested in g
;RATE  - rate of drug infusion in hours
;CMT   - compartment see below in $MODEL
;CLI   - individual predicted clearance from PK model in L/h
;VI    - individual predicted volume of distribution from PK model in L
;DOSE  - dose arm; 0, 0.1, 0.5, 1, 2, 3 mg
;SEX   - sex; 1-male, 2-female
;EVID  - event ID; 0-observation, 1-dosing
;PRET  - previous treatement; 0-naive, 1-previous treated
;ORIG  - indicator for DV; 1-FPG, 2-HbA1c, 3-Hb
;DV    - log-transformed FPG, HbA1c, Hb

$MODEL
 COMP=(PK)     ;1  PK compartment for tesaglitazar
 COMP=(FPG)    ;2  compartment for turn-over model FPG
 COMP=(HBA1C1) ;3  first non-glycosylated HB
 COMP=(HBA1C2) ;4  second non-glycosylated HB
 COMP=(HBA1C3) ;5  third non-glycosylated HB
 COMP=(HBA1C4) ;6  fourth non-glycosylated HB
 COMP=(HBA1C5) ;7  first glycosylated HB
 COMP=(HBA1C6) ;8  second glycosylated HB
 COMP=(HBA1C7) ;9  third glycosylated HB
 COMP=(HBA1C8) ;10 fourth glycosylated HB
 COMP=(VOLUME) ;11 HB dilution compartment


$PK (CALLFL=0)
;=====Residual error==================================
 RESFPG   = THETA(5)  * EXP(ETA(9))
 RESHBA1C = THETA(13) * EXP(ETA(4))
 RESHB    = THETA(16) * EXP(ETA(5))

;=====PK sub-model====================================
 CL = CLI
 V  = VI
 K  = CL/V
 S1 = V
 A_0(1) = 0

;=====FPG sub-model===================================
 BASE = THETA(1) * EXP(ETA(6))            ;BASELINE (start value at visit 1)
 KOUT = THETA(2)/24                       ;kout
 EMAX = THETA(3)                          ;Emax
 EC50 = THETA(4)* EXP(ETA(7))             ;EC50 for males
 PBO  = THETA(6)* EXP(ETA(8))             ;placebo effect
 IF(SEX.EQ.2)   EC50 = THETA(4)*(1+THETA(7))*EXP(ETA(7)) ;EC50 for females
 IF(PRET.EQ.1)  BASE = THETA(8) * EXP(ETA(6))            ;BASE for drug-naive patients
 IF(PRET.EQ.1)  PBO  = 0                                 ;placebo effect for drug-naive patients     

 KIN  = KOUT*BASE  
 A_0(2)   = BASE

;=====HbA1c sub-model=================================
     
 KGL  = THETA(10)/10000                   ;Rate constant for glucose-Hb interaction    
 MRTE = THETA(11)*24                      ;MRT for erythrocyte
 GAM  = THETA(9)*EXP(ETA(1))              ;Exponent for glucose - Hb reaction
 KINH = THETA(12)/24 * EXP(ETA(2))        ;Kin males
 IF(SEX.EQ.2) KINH = THETA(18)/24*EXP(ETA(2))    ;Kin females
              
 KUTH = 1/MRTE
 KTR  = 4   *KUTH
 GFAC = (BASE)**GAM  

 A_0(3) = KINH/(KTR + KGL * GFAC)
 A_0(4) = A_0(3) * KTR/(KTR + KGL * GFAC)
 A_0(5) = A_0(4) * KTR/(KTR + KGL * GFAC)
 A_0(6) = A_0(5) * KTR/(KTR + KGL * GFAC)

 A_0(7) =  A_0(3)* KGL * GFAC/KTR
 A_0(8) = (A_0(7)* KTR + A_0(4) * KGL * GFAC)/KTR
 A_0(9) = (A_0(8)* KTR + A_0(5) * KGL * GFAC)/KTR
 A_0(10)= (A_0(9)* KTR + A_0(6) * KGL * GFAC)/KTR

;=====Hb sub-model====================================
 KOU = THETA(17)/24                       ;kout Hb effect
 CMAX  = THETA(14)                        ;Cmax Hb effect 
 HB50  = THETA(15) * EXP(ETA(3))          ;EC50 
 A_0(11)= 1
 
$DES
  CP     = A(1)/V
  FPGE   = ( A(2)+.00001 )**GAM
  PDH     = 1+CMAX*CP/(CP+HB50)

  DADT(1)= -K*A(1)
  DADT(2) = KIN*(1+PBO)-KOUT*A(2)*(1+EMAX*CP/(CP+EC50))
  DADT(3) = KINH    -(KTR+KGL*FPGE) *A(3)
  DADT(4) = KTR*A(3)-(KTR+KGL*FPGE) *A(4)
  DADT(5) = KTR*A(4)-(KTR+KGL*FPGE) *A(5)
  DADT(6) = KTR*A(5)-(KTR+KGL*FPGE) *A(6)
  DADT(7) = KGL*FPGE*A(3)+KTR * (0  -A(7))
  DADT(8) = KGL*FPGE*A(4)+KTR *(A(7)-A(8))
  DADT(9) = KGL*FPGE*A(5)+KTR *(A(8)-A(9))
  DADT(10)= KGL*FPGE*A(6)+KTR *(A(9)-A(10))
  DADT(11)= KOU*(PDH-A(11))

$ERROR (ONLY OBSERVATION)

  AA2   = A(2)
  AA3   = A(3)
  AA4   = A(4)
  AA5   = A(5)
  AA6   = A(6)
  AA7   = A(7)
  AA8   = A(8)
  AA9   = A(9)
  AA10  = A(10)
  AA11  = A(11)
  SUM   = A(7)+A(8)+A(9)+A(10)
  RUM   = A(3)+A(4)+A(5)+A(6)
  TUM   = (SUM+RUM)

;--------FPG----------------------------------
IF(ORIG.EQ.2)       IPRED = LOG(A(2))
IF(ORIG.EQ.2)       W     = RESFPG
;---------------------------------------------

;--------HbA1c--------------------------------
IF(ORIG.EQ.1) IPRED = LOG(100*SUM/TUM)
IF(ORIG.EQ.1) W     = RESHBA1C
;---------------------------------------------

;--------Hb--------------------------------
IF(ORIG.EQ.3) IPRED = LOG(TUM/AA11)
IF(ORIG.EQ.3) W     = RESHB
;---------------------------------------------

IRES  = DV - IPRED
IWRES = IRES/W
Y     = IPRED + EPS(1)*W


$THETA   (6,8.20,10)            ; 1 BASE_FPG
$THETA   (0.0001,.0367,.1)      ; 2 Kout_FPG
$THETA   (0.4,.698,.99)         ; 3 EMAX_FPG
$THETA   (0.2,1.48,4)           ; 4 EC50_FPG
$THETA   (0.01,.0964,.2)        ; 5 prop_error_FPG
$THETA   (0.01,.164,1)          ; 6 pbo_effect_FPG
$THETA   (-.8,-.406,0)          ; 7 gender_effect_on_EC50_FPG
$THETA   (6,8.72,10)            ; 8 BASE_PRET_1_FPG

$THETA   (0.4,.743,1.5)         ; 9 Exponent_for_FPG_on_HBA1C 
$THETA   (0,.0753)              ; 10 KGL
$THETA   (1,135,333)            ; 11 MRTE
$THETA   (0.1,1.11,2)           ; 12 KINH_male
$THETA   (0.0495,.06)           ; 13 RES_ERROR_HBA1c
$THETA   (0,.682,1)             ; 14 EMAX
$THETA   (0.01,8.25,20)         ; 15 HB50_male
$THETA   (0.01,.0298,.1)        ; 16 RES_ERROR_HB
$THETA   (0,0.0305)             ; 17 KOUT
$THETA   (0.1,1.02,2)           ; 18 Kin_female
       
$OMEGA BLOCK(1) .00345          ;1 PPV_GAM
$OMEGA BLOCK(1) .00507          ;2 PPV_KINH
$OMEGA BLOCK(1) .317            ;3 PPV_HB50

$OMEGA BLOCK(1) .0682           ;4 PPV_RES_HBA1c
$OMEGA BLOCK(1) .0302           ;5 PPV_RES_Hb

$OMEGA BLOCK(1) .0184           ;6 PPV_FPG_BASELINE
$OMEGA BLOCK(1) 1.21            ;7 PPV_EC50_FPG
$OMEGA BLOCK(1) .634            ;8 PPV_PBO_FPG
$OMEGA BLOCK(1) .131            ;9 PPV_RES_FPG
$SIGMA (1 FIX)                  ; EPS1

$ESTIMATION  MAXEVAL=99990 PRINT=1 MSFO=msfb1 METHOD =1 INTER NOABORT
$COV UNCOND
