$PROB   FINAL BIG MODEL
$INPUT  ID DOSE AMT RATE TIME CMT ORIG EVID CLI VI DV STUD PRET
$ABBR   DERIV2=NO
$DATA BIG.csv IGNORE=@
$SUBR   ADVAN13 TOL=6

;-----Comments on data----------------------
;ID    - individual no
;DOSE  - dose arm of tesaglitazar; 0, 0.1, 0.25, 0.5, 1, 2, 3 mg
;AMT   - amount of tesaglitazar
;RATE  - rate of drug infusion in hours
;TIME  - time in hours
;CMT   - compartment see below in $MODEL; CMT=0 (FI and FPG)
;ORIG  - type of observation; 0-not use (dosing, initialisation), 2-FPG, 4-FI
;EVID  - event id; 0-observation, 1-dosing, 2-time point with prediction but
;        no contribution to the likelihood
;CLI   - individual predicted clearance from PK model in L/h
;VI    - individual predicted volume of distribution from PK model in L
;DV    - log-transformed FPG, FI
;STUD  - study number; 1-SIR, 2-GLAD, 6-GALLANT
;PRET  - previous treatment; 1-naive, 2/3-previous treated

$MODEL
 COMP=(BMC)    ;Beta-cell mass
 COMP=(IS)     ;Insulin sensitivity
 COMP=(PK)     ;Tesaglitazar PK

$PK (CALLFL=-1)
;=====Definition of disease group==========================================
 IF(STUD.EQ.1.AND.PRET.EQ.1) DGR = 1 ;SIR insulin-resistant
 IF(STUD.EQ.2.AND.PRET.EQ.1) DGR = 2 ;GLAD naive
 IF(STUD.EQ.6.AND.PRET.EQ.1) DGR = 3 ;GALLANT naive
 IF(STUD.EQ.2.AND.PRET.GT.1) DGR = 4 ;GLAD pre-treated
 IF(STUD.EQ.6.AND.PRET.GT.1) DGR = 5 ;GALLANT pre-treated

STRT = 10*ORIG+DGR

;=====Residual error=======================================================
 RESFPG = THETA(1) * EXP(ETA(5))
 RESFI  = THETA(2) * EXP(ETA(6))

;=====PK sub-model=========================================================
 CL = CLI
 V  = VI
 K  = CL/V

 CSS   = 0
 IF(AMT.GT.0) CSS  = RATE/CLI

;=====Insulin Sensitivity sub-model========================================
 KOUT  = THETA(3)/24   ;3.  Rate constant for S turnover
 KIN   = KOUT

 TVIS  = 0.104/24      ;Insulin sensitivity for HV
 IF(DGR.EQ.1) ISCOV = (1+THETA(10))
 IF(DGR.EQ.2) ISCOV = (1+THETA(10)) * (1+THETA(11))
 IF(DGR.EQ.3) ISCOV = (1+THETA(10)) * (1+THETA(11)) * (1+THETA(12))
 IF(DGR.EQ.4) ISCOV = (1+THETA(10)) * (1+THETA(11)) *                (1+THETA(13))
 IF(DGR.EQ.5) ISCOV = (1+THETA(10)) * (1+THETA(11)) * (1+THETA(12))* (1+THETA(14))
 IS  = TVIS * EXP(ETA(4)) * ISCOV

;Drug effect on S
 EMAS  = THETA(5)      ;5. Emax Insulin sensitivity for Galida
 TV5S  = THETA(6)      ;6. EC50 Insulin sensitivity for Galida
 EC5S  = TV5S * EXP(ETA(2)*THETA(24))

;Previous treatment effect on S
 PRES  = THETA(4)      ;4. Change in S due to pre-treatment
 IF(PRET.EQ.1) PRES  = 0

 A_0(2) = 1 + PRES

;=====FI sub-model=========================================================
 SIGM = 300/24         ;Sigma, Max insulin secretion (per mg)
 ALFA = 7.85**2        ;Alpha, EC50**2 for insulin secretion
 KI   = 432/24         ;Insulin-elimination-rate constant
 RLKI = THETA(22)      ;22. Exponential relation KI~IS/TVIS

;=====FPG sub-model========================================================
 RO  = 48.0/24         ;Glucose production (at G0)
 EGO = 1.44/24         ;Glucose effectiveness (NID)

;=====BCM sub-model========================================================
 DE  = 0.06/24         ;Death rate (at G0)
 RA  = 0.0151/24       ;Glucose dependent beta-cell adaption
 RB  = 0.000779/24     ;Glucose dependent beta-cell toxicity

;Drug effect on BCM-FPG relationship
 TV5O  = THETA(9)      ;9. EC50 On offset for Galida
 SLOP  = THETA(23)     ;23. Slope
 EC5O  = TV5O * EXP(ETA(2)*THETA(25))

;Previous treatment effect on BCM-FPG relationship
 TVPO  = THETA(8)      ;8. Reduced offset due to PRE
 IF(STUD.EQ.6) TVPO = TVPO * (1+THETA(21))
 PHI   = LOG(TVPO/(1-TVPO))
 LOGIT = EXP(PHI + ETA(1))
 PREB  = LOGIT/(1 + LOGIT)
 IF(PRET.EQ.1) PREB  = 0

;Disease status on BCM-FPG relationship
 IF (DGR.EQ.1) TVOF = THETA(15)
 IF (DGR.EQ.2) TVOF = THETA(15) + THETA(16)
 IF (DGR.EQ.3) TVOF = THETA(15) + THETA(16) + THETA(17)
 IF (DGR.EQ.4) TVOF = THETA(15) + THETA(16) +             THETA(18)
 IF (DGR.EQ.5) TVOF = THETA(15) + THETA(16) + THETA(17) + THETA(19)

 MAGN = 1
 IF (PRET.GT.1) MAGN = 1 + THETA(7)

 CORR  = THETA(20)

 OFFG = CORR + (TVOF-CORR) * EXP(MAGN*ETA(3)) ;Baseline offset
 DOFF = TVOF * EXP(MAGN*ETA(3))               ;Drug-effects can only reduce this portion

;Baseline SS solution for FPG, FI and beta-cell mass
 ROOT  = (RA/(2*RB))**2 - DE/RB
 IF (ROOT.LT.0) ROOT = 0    ;Saddle and fixed point collapsed

 BASG = RA/(2*RB) - SQRT(ROOT) + OFFG - PREB*DOFF  ;SS is offset by OFFG
 IF (BASG.LE.0) EXIT 1 3

 BASI = (RO - EGO*BASG)/(IS*(1+PRES)*BASG)
 IF (BASI.LE.0) EXIT 1 4

 BASB = BASI*KI * ((IS*(1+PRES)/TVIS)**RLKI) * (ALFA+BASG**2)/(SIGM*BASG**2)
 IF (BASB.LE.0) EXIT 1 5

 A_0(1) = BASB

;=====Definitions used in $DES (calculated in $PK to improve run-times)====
 AS   = RO**2
 DAYS = TIME/24 ; TIME as days

$DES
;=====SS solution for FPG and FI===========================================
 S  = IS*A(2)                  ;Relative change in insulin sensitivity
 KID= KI*(S/TVIS)**RLKI        ;Dynamic KI for insulin elimination
 BS = KID**2
 AX = S*SIGM*A(1)
 XX = KID*EGO+AX
 XY = AS*KID-3*EGO*XX*ALFA
 XO = (18*BS*EGO**2+45*KID*EGO*AX+27*AX**2)*ALFA
 XZ = SQRT(BS*(4*KID*(-XY)**3+AS*(2*(RO*KID)**2+XO)**2))
 ZW = 2*RO**3*KID**3+18*RO*KID**3*EGO**2*ALFA+45*RO*BS*EGO*AX*ALFA+27*RO*KID*AX**2*ALFA
 FPG=(2*RO*KID+(2*2**(1/3)*KID*XY)/(ZW+XZ)**(1/3)+2**(2/3)*(ZW+XZ)**(1/3))/(6*XX)
 IF(FPG.LE.0) EXIT 1 6

 FI = (RO - EGO*FPG)/(S*FPG)
 IF(FI.LE.0) FI = 1E-3

 CP   = A(3)/V
 IF(CP.LT.0) CP=0
 EFFB = CP**SLOP/(CP**SLOP + EC5O**SLOP)    ;Drug effect on BCM-FPG relationship
 EFFS = EMAS*CP/(CP + EC5S)                 ;Drug effect on insulin sensitivity
 GLUC = FPG - OFFG + EFFB * DOFF            ;Beta-cell adaption

 DADT(1) = (-DE + RA*GLUC - RB*GLUC**2)*A(1) ;beta-cell concentration
 DADT(2) = KIN*(1+EFFS) - KOUT*A(2)          ;insulin sensitivity ratio
 DADT(3) = -K*A(3)                           ;drug amount

$ERROR
;=====SS solution again====================================================
  BCM  = A(2)
  SENS = A(1)
;FPG
  INS = IS * BCM
  DD  = INS * SIGM * SENS
  KIDY= KI*(INS/TVIS)**RLKI
  BS2 = KIDY**2
  DX  = KIDY*EGO + DD
  DY  = AS*KIDY - 3*EGO*DX*ALFA
  X0  = (18*BS2*EGO**2 + 45*KIDY*EGO*DD + 27*DD**2)*ALFA
  DZ  = SQRT(BS2*(4*KIDY*(-DY)**3 + AS*(2*(RO*KIDY)**2 + X0)**2))
  DW  = 2*RO**3*KIDY**3 + 18*RO*KIDY**3*EGO**2*ALFA + 45*RO*BS2*EGO*DD*ALFA + 27*RO*KIDY*DD**2*ALFA
  FPG2=(2*RO*KIDY + (2*2**(1/3)*KIDY*DY)/(DW+DZ)**(1/3)+2**(2/3)*(DW+DZ)**(1/3))/(6*DX)
  IF(FPG2.LE.0) FPG2 = 1E-6

;FI
  FI2 = (RO - EGO * FPG2)/(INS * FPG2)
  IF(FI2.LE.0)  FI2 =1E-6

 IF (ORIG.EQ.2) THEN ;Observations of FPG
  IPRED = LOG(FPG2)
  W     = RESFPG
 ENDIF

 IF (ORIG.EQ.4) THEN ;Observations of FI
  IPRED = LOG(FI2)
  W     = RESFI
 ENDIF

 IRES  = DV - IPRED
 IWRES = IRES/W
 Y = IPRED + EPS(1)*W
 
$THETA (0, 0.0800)       ;1.  RES_FPG
$THETA (0, 0.309)        ;2.  RES_FI
$THETA (0, 0.0598)       ;3.  Rate constant for Insulin Sensitivity (/day)
$THETA (-1,0.196)        ;4.  Change in S due to pre-treatment
$THETA (0, 9.69)         ;5.  Emax, Insulin sensitivity for tesaglitazar
$THETA (0, 7.62)         ;6.  EC50, Insulin sensitivity for tesaglitazar
$THETA (-1,0.491)        ;7.  Change in beta-cell adaption-IIV for pretreated
$THETA (0, 0.270, 2)     ;8.  Reduced beta-cell adaption due to pretreatment
$THETA (0, 0.463)        ;9.  EC50 on beta-cell adaption for tesaglitazar
$THETA (-1, -0.190, 0)   ;10. Difference in S between Topp and current
$THETA (-1, -0.212, 0)   ;11. Difference in S between IR and T2DM
$THETA (-1, -0.224, 0)   ;12. Difference in S between GLAD and GALLANT
$THETA (-1, -0.0164,1)  ;13. Difference in S between naive and pretreat in GLAD
$THETA (-1, 0.215,  1)   ;14. Difference in S between naive and pretreat in GALLANT
$THETA (0, 0.199)        ;15. Difference in offset FPG-adaptation between Topp and current
$THETA (0, 2.92)         ;16. Difference in offset FPG-adaptation between IR and T2DM
$THETA (0, 0.396)        ;17. Difference in offset FPG-adaptation between GLAD and GALLANT
$THETA (-3,0.801)        ;18. Difference in offset FPG-adaptation between naive and pretreat in GLAD
$THETA (-3,-0.438)       ;19. Difference in offset FPG-adaptation between naive and pretreat in GALLANT
$THETA (-3, -1.64)       ;20. Correction of the offset distribution
$THETA (-1, 0.953)       ;21. Difference in PREB GLAD->GALLANT
$THETA (0, 0.652)        ;22. Exponential relation KI~IS/TVIS
$THETA (0, 1.12)         ;23. Gamma on sigmoidal drug effect
$THETA (0, 0.482)        ;24. IIV-potency of drug effect S
$THETA (0, 1.04)         ;25. IIV-potency of drug effect BCM-FPG

$OMEGA          1.26     ;1. PREB
$OMEGA          1 FIX    ;2. Potency of drug effect
$OMEGA BLOCK(2) 
0.0672   ;3. beta-cell adaption
-0.0546 0.32     ;4. Insulin sensitivity
$OMEGA BLOCK(2) 
0.223    ;5. RES FPG
0.0788 0.0579  ;6. RES FI

$SIGMA 1 FIX  ; RUV_EPS

$ESTIMATION MAXEVAL=9990 PRINT=1 NOABORT MSFO=MSFOBIG METHOD=1 INTER SIGDIGITS=4
$COVARIANCE

