$PROBLEM MODEL FOR INSULIN, GLUCOSE and HOT GLUCOSE after IVGTT
$INPUT OID TIME AMT ODV INSU TOTG CMT BW EVID RATE DV ID TYPE FRST=DROP
;  DV contains insulin, glucose as well as hot glucose
$DATA 42pat_nohot.csv IGNORE=@
; 42 patients are included
; 5-min insulin infusion at 20 minutes.
; insulin dose 50 mU/L

$ABB DERIV2=NO
$SUBS ADVAN6 TRANS1 TOL=5 
$MODEL
 COMP = TOT_C   ;1 Glucose central compartment
 COMP = INS_C   ;2 Insulin central compartment
 COMP = HOT_C   ;3 Hot glucose central compartment
 COMP = TOT_E   ;4 Glucose effect compartment 1
 COMP = PER_C   ;5 Glucose peripheral compartment
 COMP = PER_I   ;6 Glucose effect compartment 2
 COMP = PER_H   ;7 Hot glucose peripheral compartment
 COMP = INS_E   ;8 Insulin effect compartment

$PK 

;---------------------Increasing number of iterations-------
"FIRST
"      COMMON/PRCOMG/ IDUM1,IDUM2,IMAX,IDUM4,IDUM5
"INTEGER IDUM1,IDUM2,IMAX,IDUM4,IDUM5
"IMAX=5000000
;---------------------Handling baseline values--------------
REPL=IREP

  GSS = THETA(11)*EXP(ETA(11))
  ISS = THETA(12)*EXP(ETA(12))

;---------------------Initializing parameters---------------
  VG  = THETA(1)*EXP(ETA(1))*BW/70      ;Central volume for glucose
  Q   = THETA(2)*EXP(ETA(2))            ;k12 for glucose
  VI  = THETA(3)*EXP(ETA(3))*BW/70      ;central volume for insulin
  CLI = THETA(4)*EXP(ETA(5))            ;k10 for insulin disappear
  VP  = THETA(5)*EXP(ETA(7))            ;k21 for glucose
  KGE2= THETA(6)*EXP(ETA(8))           ;k12 for insulin
  KIE = THETA(7)*EXP(ETA(9))           ;keo for insulin
  IPRG= THETA(8)*EXP(ETA(10))           ;influence of glucose on insulin production
;---------------------Initializing patient parameters---------
  CLG = THETA(9)*EXP(ETA(4))            ;k10 for glucose disappear
  CLGI= THETA(10)*EXP(ETA(6))/1000      ;2nd order rate constant for insulin-dep. glucose elimination
;----------------------Residual error parameters--------------
  REST= THETA(13)
  RESI= THETA(14)
  RESH= THETA(15)
  RESE= THETA(16)                       ;correction factor for early residual error
;----------------production and initializing compartments------------
  K15 = Q/VG                            ;rate const gluc disp
  K51 = Q/VP                            ;rate const gluc disp
  KG  = CLG/VG                          ;rate const glucose disappear
  KGI = CLGI/VG                         ;2nd order rate constant for insulin-dep. glucose elimination
  KI  = CLI/VI                          ;duration of insulin infusion
  GPRO= GSS*(KG+KGI*ISS)*VG             ;baseline glucose production
  IPRO= KI*ISS*VI                       ;baseline insulin production
;----------Initializing compartments-------------
;  F1  = BW/10                            ;correction for glucose in mg/dl
IF(AMT.EQ.1) F1=GSS*VG                         
  F2  = 0
IF(AMT.EQ.1) F2=ISS*VI
  F3  = BW/10        
  F4  = GSS
  F5  = K15*GSS*VG/K51
  F6  = GSS
  F7  = 0
  F8  = ISS
;-----------Initializing compartments for patients-------------
IF(TYPE.EQ.2) F1  = 1/10                  ;correction for glucose in mg/dl
IF(TYPE.EQ.2.AND.AMT.EQ.1) F1=GSS*VG                         
IF(TYPE.EQ.2)   F2  = ISS*VI
IF(TYPE.EQ.2.AND.TIME.GT.0) F2=1
IF(TYPE.EQ.2)  F3  = 0.26/10

$DES
PTOT   = K15*A(1)-K51*A(5)             ;distribution of tot glucose
PHOT   = K15*A(3)-K51*A(7)             ;distribution of hot glucose
IGPR   = (A(6)/GSS+.0001)**IPRG        ;glucose on insulin production

GPRD   = GPRO                          ;glucose production
IPRD   = IPRO*IGPR                     ;insulin production

TELI   = (KG + KGI*A(8))*A(1)          ;tot glucose elimination
IELI   =      KI        *A(2)          ;insulin elimination
HELI   = (KG + KGI*A(8))*A(3)          ;hot glucose elimination

DADT(1) = GPRD - TELI - PTOT           ;cent tot gluc
DADT(2) = IPRD - IELI                  ;cent ins
DADT(3) =      - HELI - PHOT           ;cent hot gluc
DADT(4) = 0 
DADT(5) = PTOT                         ;per tot gluc
DADT(6) = KGE2*(A(1)/VG - A(6))        ;tot glucose effect compartment
DADT(7) = PHOT                         ;per hot gluc
DADT(8) = KIE*(A(2)/VI - A(8))         ;insulin effect-compartment

$ERROR
CTOT    =A(1)/VG
CINS    =A(2)/VI
CHOT    =A(3)/VG
TEF1    =A(4)
TPER    =A(5)
TEF2    =A(6)
HPER    =A(7)
IEFF    =A(8)

IF (CMT.EQ.1) IPRED = CTOT+.00001
IF (CMT.EQ.2) IPRED = CINS+.00001
IF (CMT.EQ.3) IPRED = CHOT+.00001
IF (CMT.GE.4) IPRED = 1

IF (CMT.EQ.1) W = REST
IF (CMT.EQ.2) W = RESI
IF (CMT.EQ.3) W = RESH
IF (CMT.GE.4) W = 1
IF(TIME.LE.2) W = W*RESE

IRES  = DV-LOG(IPRED)
IWRES = IRES/W
Y     = LOG(IPRED) + ERR(1)*W
PRD   = IPRED
IPRED = LOG(IPRED)
OBS   = ODV

;parameter estimates from /hannas/Diabetes/Comb_final/August08/run700.lst
$THETA (0,8.92)        ;1 VG  (L)
$THETA (0,0.583)       ;2 Q
$THETA (3,6.17)        ;3 VI
$THETA (0,1.21)        ;4 CLI  (/min)
$THETA (0,9.57)        ;5 VP
$THETA (0,0.0299)      ;6 KGE2
$THETA (0,0.021)       ;7 KIE
$THETA (0,1.39)        ;8 IPRG
$THETA (0,0.0281)      ;9 CLGpat  (/min)
$THETA (0,2.99)        ;10 CLGIpat (/min/pM)
$THETA (0,159)         ;11 GSS
$THETA (0,11.5)        ;12 ISS
$THETA (0,0.0415)      ;13 REST
$THETA (0,0.253)       ;14 RESI
$THETA (0,0.511)       ;15 RESH
$THETA (0,3.20)        ;16 EARLY ERROR
;---------

$OMEGA BLOCK(3) 0.076               ;1 VG
                -0.138  0.66        ;2 Q  
                0.0708 -0.0294 0.17 ;3 VI
$OMEGA 0.361                        ;4 CLG 
$OMEGA 0.0858                       ;5 CLI 
$OMEGA 0.289                        ;6 CLGI
$OMEGA 0.2                          ;7 VP
$OMEGA 0.757                        ;8 KGE2
$OMEGA 0.353                        ;9 KIE
$OMEGA 0.13                         ;10 IPRG
$OMEGA 0.0411                       ;11 GSS
$OMEGA 0.242                        ;12 ISS

$SIGMA 1 FIX 

;$SIM (123456) NSUB=1000 ONLYSIM
$EST MAXEVAL=9999 PRINT=1 POSTHOC MSFO=msfb METH=0 

;$TABLE ID TIME DV CMT EVID CTOT CINS CHOT NOHEAD NOAPP NOPRINT FILE=sim10b
