$PROB  FINAL OGGT IGI MODEL FOR T2DM
$INPUT ID TIME AMT ODV DV INSU TOTG CMT EVID RATE BW OCC
$DATA  data.prn IGNORE=@
$ABB   DERIV2=NO
$SUBS  ADVAN6 TRANS1 TOL=5

;-----Comments on data----------------------
;ID    - individual no
;TIME  - time in minutes
;AMT   - amount of glucose ingested in mg
;ODV   - untransformed DV; glucose in mg/dL, insulin in mU/L
;DV    - log-transformed glucose, insulin & hot glucose
;INSBL - individual insulin at start of experiment
;GLUBL - individual glucose at start of experiment
;CMT   - compartment see below in $MODEL
;BW    - body weight in kg
;EVID  - event ID; 0-observation, 1-dosing
;OCC   - IVGTT=0, OGTT=1

$MODEL
 COMP = GLU_C   ;1 central compartment glucose
 COMP = INS_C   ;2 central compartment insulin
 COMP = HOT_C   ;3 central compartment hot glucose
 COMP = GLU_E   ;4 effect compartment for glucose on insulin
 COMP = GLU_P   ;5 peripheral glucose compartment
 COMP = HOT_P   ;6 peripheral hot glucose compartent
 COMP = INS_E   ;7 effect compartment for insulin

$PK 
;=====Indicator variables=============================
 OGTT  = OCC         ;1 if OGTT, 0 if IVGTT
 IVGTT = 1 - OCC     ;0 if OGTT, 1 if IVGTT
 IOV   =-(2*OCC - 1) ;-1 if OGTT, 1 if IVGTT

;=====Residual error==================================
 RESGIV = THETA(17)
 RESGPO = THETA(23)
 RESG   = RESGIV*IVGTT + RESGPO*OGTT
 RESI   = THETA(18)
 RESH   = THETA(19)**IVGTT  
 RESE   = THETA(20)**IVGTT

;=====Glucose sub-model===============================
;baseline
 IF(EVID.GT.2) BASG=TOTG
 GSCALE = THETA(21)
 IIVG = ETA(18)*IVGTT + ETA(19)*OGTT
 GSS  = BASG*EXP(IIVG*RESGIV) * GSCALE**IVGTT
;for simulation
;GSS = (THETA(21)*IVGTT + THETA(24)*OGTT)*EXP(IIVG)

;absorption
 BIOG= THETA(12)*EXP(ETA(12))          ;biovailability glucose
 MTT = THETA(13)*EXP(ETA(13))          ;mean transit time glucose
 NN  = THETA(14)*EXP(ETA(14))          ;number of transit compartments for glucose
 KTR  = NN/MTT
 LNFAC = LOG(2.5066)+(NN+0.5)*LOG(NN)-NN+LOG(1+1/(12*NN))

;distribution
 VG  = THETA(1)*EXP(ETA(1))*BW/70      ;central volume for glucose (in l)
 Q   = THETA(2)*EXP(ETA(2))            ;glucose flow central-peripheral
 VP  = THETA(8)*EXP(ETA(8)+ETA(17)*IOV) ;pripheral volume for glucose

;elimination
 CLG   = THETA(4)*EXP(ETA(4))          ;glucose CL from central comp
 CLGIIV= THETA(5)*EXP(ETA(5))
 CLGIPO= THETA(6)*EXP(ETA(6))
 CLGI  = CLGIIV*IVGTT + CLGIPO*OGTT

 K15 = Q/VG
 K51 = Q/VP
 KG  = CLG/VG                          ;k10 for glucose dissappearance
 KGI = CLGI/VG                         ;2nd order rate constant for insulin-dep. glucose elimination

;unit conversion and dosing
 GDOSE = 300*BW
 IF(ID.EQ.26) GDOSE = 272.4771*BW
 F1  = GDOSE/10                        ;correction for glucose in mg/dl
 F3  = GDOSE*0.26/10                   ;correction for hot glucose

;initialization
 A_0(1) = GSS*VG                       ;baseline glucose
 A_0(3) = 0                            ;baseline hot glucose
 A_0(5) = K15*GSS*VG/K51               ;glucose peripheral compartment initialization
 A_0(6) = 0                            ;hot glucose peripheral compartment
  
;=====Insulin sub-model==============================
;baseline
 IF(EVID.GT.2) BASI=INSU
 ISCALE = THETA(22)
 IIVI = ETA(20)*IVGTT + ETA(21)*OGTT
 ISS = BASI*EXP(IIVI*RESI) * ISCALE**IVGTT
;for simulation
;ISS = (THETA(22)*IVGTT + THETA(25)*OGTT)*EXP(IIVI)

;distribution
 VI  = THETA(3)*EXP(ETA(3))*BW/70      ;central volume for insulin

;elimination
 CLI = THETA(7)*EXP(ETA(7))            ;insulin CL

 KI  = CLI/VI                          ;k10 for insulin elimination

;unit conversion and dosing
 IDOSE = 50*BW
 F2  = IDOSE

;initialization
 A_0(2) = ISS*VI                       ;baseline insulin

;=====Feed-back control==============================
;glucose on insulin secretion
 KEOG= THETA(9)*EXP(ETA(9))          ;keo for glucose 

;insulin on glucose elimination
 KEOI= THETA(10)*EXP(ETA(10))          ;keo for insulin
 IPRG= THETA(11)*EXP(ETA(11))          ;influence of glucose on insulin production

;incretin effect on insulin secretion
 EMAX = THETA(15)*EXP(ETA(15))         ;max effect of glucose abs on insulin prod
 CA50 = THETA(16)*EXP(ETA(16))         ;conc of 50% effect
                                                                                                                       
;initialization
 A_0(4) = GSS                          ;glucose effect (on ins.) compartment initialization
 A_0(7) = ISS                          ;insulin effect compartment initialization

;=====Endogenous production/secretion================
;Glucose
 GPRO= GSS*(KG+KGI*ISS)*VG             ;baseline glucose production

;Insulin
 IPRO= KI*ISS*VI                       ;baseline insulin production

$DES
;=====Feed-back=======================================
;glucose absorption
 TGLU   = EXP(LOG(75000*(BIOG/10))+LOG(KTR)+NN*LOG(KTR*T+.00001)-KTR*T-LNFAC)

;incretin
 IGAPR  = 1 + TGLU*EMAX/(TGLU+CA50)*OGTT       ;glucose absorption on insulin production

;glucose on insulin secretion
 IGPR   = (A(4)/GSS+.0001)**IPRG        ;glucose on insulin production

;=====Glucose=========================================
 GPR   = GPRO                         ;glucose production

 PTOT   = K15*A(1)-K51*A(5)             ;distribution of tot glucose
 TELI   = (KG + KGI*A(7))*A(1)          ;tot glucose elimination

 PHOT   = K15*A(3)-K51*A(6)             ;distribution of hot glucose
 HELI   = (KG + KGI*A(7))*A(3)          ;hot glucose elimination

;=====Insulin=========================================
 IPRD   = IPRO*IGPR*IGAPR             ;insulin production

 IELI   =  KI*A(2)                      ;insulin elimination

 DADT(1) = GPR  - TELI - PTOT + TGLU*OGTT
 DADT(2) = IPRD - IELI   
 DADT(3) =      - HELI - PHOT
 DADT(4) = KEOG*(A(1)/VG - A(4))        ;glucose effect compartment
 DADT(5) = PTOT
 DADT(6) = PHOT
 DADT(7) = KEOI*(A(2)/VI - A(7))        ;insulin effect-compartment

$ERROR
 GLUC    =A(1)/VG
 INSC    =A(2)/VI
 HOTC    =A(3)/VG
 GLUE    =A(4)
 GLUP    =A(5)
 HOTP    =A(6)
 INSE    =A(7)
       
 IF(CMT.EQ.1) IPRED = GLUC+.00001
 IF(CMT.EQ.2) IPRED = INSC+.00001
 IF(CMT.EQ.3) IPRED = HOTC+.00001
 IF(CMT.GE.4) IPRED = 1

 IF (CMT.EQ.1) W = RESG
 IF (CMT.EQ.2) W = RESI
 IF (CMT.EQ.3) W = RESH
 IF (CMT.GE.4) W = 1
 IF(TIME.LE.2) W = W*RESE

 IRES  = DV - LOG(IPRED)
 IWRES = IRES/W
 Y = LOG(IPRED) + ERR(1)*W
 PRD   = IPRED
 IPRED = LOG(IPRED)
 OBS = ODV


$THETA 9.33    FIX         ;1  ~VG_FIX
$THETA 0.442   FIX         ;2  ~Q_FIX
$THETA 6.09    FIX         ;3  ~VI_FIX
$THETA 0.0287  FIX         ;4  ~CLG_FIX
$THETA 0.00297 FIX         ;5  ~CLGI_FIX
$THETA (0,0.00590)         ;6  ~CLGI_PO
$THETA 1.22    FIX         ;7  ~CLI_FIX
$THETA 8.56    FIX         ;8  ~VP_FIX
$THETA 0.0289  FIX         ;9 ~KEOG_FIX
$THETA 0.0213  FIX         ;10 ~KEOI_FIX
$THETA 1.42    FIX         ;11 ~IPRG_FIX
$THETA (0,0.811, 1)        ;12 ~BIOG
$THETA (0,34.9)            ;13 ~MTT
$THETA (0,1.27)            ;14 ~NN
$THETA (0,1.47)            ;15 ~EMAX
$THETA (0,14.8)            ;16 ~CA50

$THETA 0.0436  FIX         ;17 ~RESG_FIX
$THETA 0.252   FIX         ;18 ~RESI_FIX
$THETA 0.0512  FIX         ;19 ~RESH_FIX
$THETA 3.31    FIX         ;20 ~RESE_FIX

$THETA 0.891   FIX         ;21 ~SCALE_GSS_IV_FIX
$THETA 0.93    FIX         ;22 ~SCALE_ISS_IV_FIX
;$THETA (0,158)              ;21 ~GSS IV SIM
;$THETA (0,11.5)             ;22 ~ISS IV SIM
$THETA (0,0.0732)          ;23 ~RESG_PO
;$THETA (0,179)             ;24 ~GSS PO SIM
;$THETA (0,7.15)            ;25 ~ISS PO SIM
;-------------------------------------------------
$OMEGA BLOCK(3) .0887 FIX          ;1  ~IIV_VG_FIX
                -0.192 .73         ;2  ~IIV_Q_FIX
                .0855 -0.12 .165   ;3  ~IIV_VI_FIX

$OMEGA 0.352  FIX          ;4  ~IIV_CLG_FIX
$OMEGA BLOCK(2) .227    FIX   ;5  ~IIV_CLGI
                .169 .207  ;6  ~IIV_CLGI_PO

$OMEGA 0.0852 FIX          ;7  ~IIV_CLI_FIX
$OMEGA 0.0891 FIX          ;8  ~IIV_VP_FIX
$OMEGA 0.728  FIX          ;9  ~IIV_KEOG_FIX
$OMEGA 0.337  FIX          ;10 ~IIV_KEOI_FIX 
$OMEGA 0.124  FIX          ;11 ~IIV_IPRG_FIX
$OMEGA 0      FIX          ;12 ~IIV_BIOG_FIX 
$OMEGA 0.0117           FIX   ;13 ~IIV_MTT
$OMEGA 0      FIX          ;14 ~IIV_NN_FIX
$OMEGA 0.295            FIX   ;15 ~IIV_EMAX
$OMEGA 1.26             FIX   ;16 ~IIV_CA50
$OMEGA 0.0238           FIX   ;17 ~IOV_VP

$OMEGA 1      FIX          ;18 ~IIV_GSS_IV_FIX
$OMEGA 1      FIX          ;19 ~IIV_GSS_PO_FIX
$OMEGA 1      FIX          ;20 ~IIV_ISS_IV_FIX
$OMEGA 1      FIX          ;21 ~IIV_ISS_PO_FIX
;$OMEGA BLOCK(1) 0.0610     ;18 ~IIV_GSS_IV_FIX
;$OMEGA BLOCK(1) 0.0687     ;19 ~IIV_GSS_PO_FIX
;$OMEGA BLOCK(1) 0.128      ;20 ~IIV_ISS_IV_FIX
;$OMEGA BLOCK(1) 0.209      ;21 ~IIV_ISS_PO_FIX

$SIGMA 1      FIX          ;~RES_FIX

;$SIML (87568767) 
$EST MAXEVAL=9990 PRINT=1 MSFO=msfb_final METH=1 
$COVARIANCE PRINT=E
;$TABLE ID TIME AMT ODV DV INSU TOTG CMT EVID RATE BW OCC
;       NOAPP ONEHEAD NOPRINT FILE=IGI_OGTT_sim_data.prn
