$PROB   MODEL OF MYELOSUPPRESSION (WBC) FOR PACLITAXEL
  ; Friberg et al., JCO, 2002
  ; In this example empirical Bayes estimates of the PK parameters are in
  ; The DATAFILE (CLI, V2I AND V1I. Q IS THE SAME FOR ALL IDS)
$INPUT C ID TIME RATE AMT DV CMT EVID CLI V2I V1I
$DATA data_ddmore_WBC_pacl.csv IGN=@
$SUBS   ADVAN6 TOL=5
$MODEL  NCOMP=7
        COMP=(CENTRAL)       ; Central PK compartment
        COMP=(PERI)      ; Peripheral PK compartment
        COMP=(CIRC,DEFOBS)   ; Circulating cells (observed)
        COMP=(PROLIF)      ; Proliferative, drug-sensitive cells           
        COMP=(TRANSIT1)      ; Transit compartment No 1
        COMP=(TRANSIT2)      ; Transit compartment No 2
        COMP=(TRANSIT3)      ; Transit compartment No 3

$PK
        CL    =  CLI    ; INDIVIDUAL PK PARAMETERS IN DATA FILE
        V1    =  V1I
        Q     =  204   ; No IIV in this parameter
        V2    =  V2I
        S1    =  V1
        K     =  CL/V1
        K12   =  Q/V1
        K21   =  Q/V2
        CIRC0 =  THETA(1)*EXP(ETA(1))   ; Baseline cell count
        MTT   =  THETA(2)*EXP(ETA(2))
        KTR   =  4/MTT
        ; Initialization of compartments related to myelosuppression model 
     ; When all rate constants = KTR, then initialization of all 
         ; compartments = CIRC0
     A_0(3) =  CIRC0
        A_0(4) =  CIRC0
        A_0(5) =  CIRC0
        A_0(6) =  CIRC0
        A_0(7) =  CIRC0
        SLOPU  =  THETA(3)*EXP(ETA(3))
        GAM    =  THETA(4)
        
$DES
        
;-------PK -------------------------

  DADT(1)  = -K*A(1) - K12*A(1) + K21*A(2)        
  DADT(2)  = -K21*A(2) + K12*A(1)

;------PD-------------------------------
  
  CONC     = A(1)/V1
  DRUG     = SLOPU*CONC       ; Linear relationship

;-------Myelosuppression----------------------

 DADT(3) = - KTR*A(3) + KTR*A(7)      ;CIRC
 DADT(4) = - KTR*A(4) + KTR*A(4)*(1-DRUG)*(CIRC0/A(3))**GAM
 DADT(5) = - KTR*A(5) + KTR*A(4)
 DADT(6) = - KTR*A(6) + KTR*A(5)
 DADT(7) = - KTR*A(7) + KTR*A(6)

$ERROR
  IPRED  =  A(3)
  W      =  THETA(5)*IPRED
  IRES   =  DV -  IPRED
  IWRES  =  IRES/W
  Y      =  IPRED+W*EPS(1)

; For table output of compartment amounts
AA1 = A(1)/V1  ; Drug concentration in central compartment
AA2 = A(2)
AA3 = A(3)
AA4 = A(4)
AA5 = A(5)
AA6 = A(6)
AA7 = A(7)

$THETA  (2,7.21,13)           ;1 CIRC0 Baseline cell count
$THETA  (0,124)               ;2 MTT
$THETA  (0,28.9)              ;3 SLOPU
$THETA  (0,0.239)             ;4 GAM
$THETA  (0,0.286)             ;5 prop_err
$OMEGA   0.107                 ;1 IIV_CIRC0
$OMEGA   0.0296               ;2 IIV_MTT
$OMEGA   0.176               ;3 IIV_SLOPU
$SIGMA   1 FIX ; EPS

$EST  MAXEVALS=0 POSTHOC PRINT=1  METHOD=1 INTER
;$COV

$TABLE ID TIME IPRED IWRES NOPRINT ONEHEADER FILE=sdtab1
$TABLE ID CIRC0 SLOPU MTT GAM AA3 AA4 NOPRINT ONEHEADER FILE=patab1

