$PROB TUMOUR EXPOSURE
; Tham LS, Wang L, Soo RA, Lee SC, Lee HS, Yong WP, Goh BC, Holford NH. 
; A pharmacodynamic model for the time course of tumor shrinkage by gemcitabine +
; carboplatin in non-small cell lung cancer patients. 
; Clin Cancer Res 2008; 14: 4213-8.
$INPUT ID TIME AMT DV
$DATA tumour_exposure.csv

$EST MAX=9990 NSIG=3 SIGL=9 NOABORT PRINT=1
METHOD=CONDITIONAL INTERACTION
MSFO=size.msf
$COV

$THETA
(1,6.66,10) ; POP_SIZE0 cm
(1,18.9,200) ; POP_TOVER week
(1,11700.,100000) ; POP_AE50 mg 
(1,8.27,100000) ; POP_TEQ week

$OMEGA
0.317 ; PPV_SIZE0
0.082 ; PPV_TOVER
1.9 ; PPV_AE50

$SIGMA 
0.0358 ; RUV_CV
0.0125 ; RUV_SD cm^2

$SUBR ADVAN13 TOL=9
$MODEL
   COMP=DRUG
   COMP=TUMOUR

$PK

   GSIZE0=THETA(1)
   SIZE0=GSIZE0*EXP(ETA(1))
   GTOVER=THETA(2)*168 ; week -> h
   TOVER=GTOVER*EXP(ETA(2))
   
   ; gemcitabine AMT in data is umole (263g/mole)
   GAE50=THETA(3)/263*1000 ; mg -> umole
   AE50=GAE50*EXP(ETA(3))
   ; time in data is hours
   GTEQ=THETA(4)*168 ; week -> h
   TEQ=GTEQ

   KOVER=1/TOVER
   A_0(2)=SIZE0
   RIN=SIZE0*KOVER

   KPD=LOG(2)/TEQ
   S1=1

$DES
   ; State variables for DE solver
   DAE=A(1) ; amount in effect compartment
   DSIZE=A(2) ; tumour size
   PD=1 - DAE/(AE50+DAE) ; Emax pharmacodynamic model
   DADT(1) = -KPD*A(1) ; Bolus dose (in data) enters implicitly
   DADT(2) = (RIN*PD - DSIZE*KOVER)*DSIZE

$ERROR

   ; State variable solution
   AE=A(1) ; amount in effect compartment
   SIZE=A(2) ; tumour size

   Y=SIZE*(1 + ERR(1)) + ERR(2)

;$TABLE ID TIME AMT CMT DV MDV DVID DOSE 
;AUCG AUCI AUCE TK0 SEX AGE RACE KPS STGE
;NOAPPEND
;ONEHEADER NOPRINT FILE=size.fit


