$PROBLEM    Asenapine in acute schizophrenia
$INPUT      ID TIME DV STUD DDUR HOSP US AUC MDV
$DATA       PANSSdata.csv IGNORE=@

; Explanation of the columns in the dataset
; ID = ID number
; STUD = study number, first digit indicating whether the study was phase II or phase III, second digit indication substudy
; TIME = time in days since start of study
; DV = observed PANSS score
; DDUR = duration of current episode.
;        1 = less 2 weeks, 2 = between 2 weeks and 1 month, 3 = 1 - 6 months, 4 = 6 - 12 months, 5 = more than 1 year.
; HOSP = patient hospitalized at time of observation (no = 0, yes = 1)
; US = Study performed in the US (no = 0, yes = 1)
; AUC = area under concentation - time curve in g*h/l

$PRED
DDU    = 0     ; duration of current episode < 1 month
IF(DDUR.GT.2) DDU = 1 ; duration > 1 month

PHASE  = 0                      ; phase II study 
IF(STUD.GT.30) PHASE = 1		; phase III study

TVP0   = THETA(1)*(1+THETA(3)*DDU)            ; baseline PANSS
IF(PHASE.EQ.1) TVP0 = THETA(2)*(1+THETA(3)*DDU)
PAN0   = TVP0 + ETA(1)

TVPX   = (THETA(4) * (1+THETA(5)*PHASE))        ; maximum placebo response
PMAX   = TVPX + ETA(2)
TP     = THETA(6)                               ; time-course parameter for placebo response
POW    = THETA(7)                               ; power of weibull function
PMOD   = PMAX*(1-EXP(-(TIME/TP)**POW))          ; placebo model

FT     = TIME/42                                ; time-course parameter for asenapine response
IF(TIME.GT.42) FT =1
AUC50  = THETA(8)*EXP(ETA(3))                   ; EC50 of asenapine AUC
EMAX   = THETA(9)                               ; Emax of asenapine
EFF    = EMAX*AUC/(AUC50+AUC) * FT              ; asenapine effect

EMOD   = 0
IF(TIME.GT.0.AND.AUC.GT.0) EMOD = EFF           ; PANSS scores at times other than baseline
PSCR  = PAN0*(1-PMOD)*(1-EMOD)                  

IPRED  = PSCR

CHOSP = 1 
; influence of not being hospitalized on residual error:
IF(HOSP.EQ.0) CHOSP = ( 1 + THETA(10))  
TVW    = CHOSP*(THETA(11)*(1+THETA(12)*US))     ; residual variability (variance) including the effect of the study being performed in the US

W  = TVW*EXP(ETA(4))
Y  = IPRED+W*EPS(1)
IRES  = DV-IPRED
IWRES = IRES/W

$THETA
; the initial estimates are the final parameter estimates.
 94        ; 1 PAN0_baseline_PANSS_phase_II_studies
 90.5      ; 2 PAN0_baseline_PANSS_phase_III_studies
 -0.0339   ; 3 difference_PANSS_baseline_chronic_patients
 0.0859    ; 4 Pmax_maximum_placebo_effect_phase_II
 0.688     ; 5 difference_maximum_placebo_effect_with_phase_III_study (proportional)
 (0, 13.2) ; 6 TP_time_course_placebo_response [days]
 (0, 1.24) ; 17 POW_power_parameter_weibull_function
 82        ; 8 AUC50_AUC at which half the maximum asenapine effect is obtained
 0.191     ; 9 Emax_maximum_asenapine_effect
 -0.145    ; 10 difference_in_residual_error_hospitalized_patients
 3.52      ; 11 typical_residual_error 
 0.623     ; 12 difference_in_residual_error_in_US_based_studies

$OMEGA  BLOCK(2)
; final parameter estimates
 167           ; 1 PAN0
 -0.395 0.0249 ; 2 PMAX
$OMEGA  21.7   ; 3 AUC50
 0.196         ; 4 Res_err

$SIGMA  1  FIX ; EPS

$ESTIMATION MAX=9999 PRINT=5 METHOD=1 INT
$COVARIANCE PRINT=E

$TABLE      ID TIME IPRED IWRES ONEHEADER NOPRINT FILE=sdtab1
$TABLE      ID ETA1 ETA2 ETA3 ETA4 ONEHEADER NOPRINT FILE=patab1
$TABLE      ID STUD DDUR US ONEHEADER NOPRINT FILE=catab1
;$TABLE ID ONEHEADER NOPRINT FILE=cotab1

