$PROB   Agonist-antagonist interaction model for Prolactin, Friberg et al. CPT 2009
 	; Control stream with predicted individual PKprofiles from PK parameters in data file 
 	; and PK compartments

$INPUT  ID STUD TRT OCC DAT1=DROP TIME CMT AMT RATE EVID SEX 
       	 CLI VCI VPI QI KAI FI DURI ALAG DV PAT SS II CONC
$DATA   prolactin.dta   IGNORE=#
       
$SUBROUTINES ADVAN6 TOL=5 
$MODEL
    COMP = (ABS)       	; 1 Absorption compartment
    COMP = (CENT)    	; 2 Central PK compartment
    COMP = (PERI)     	; 3 Peripheral PK compartment
    COMP = (PROL)  	; 4 Prolactin compartment
    COMP = (DA)       	; 5 Hypothetical dopamine compartment

$PK
    "FIRST
    " COMMON/PRCOMG/IDUM1,IDUM2,IMAX,IDUM4,IDUM5
    "INTEGER IDUM1,IDUM2,IMAX,IDUM4,IDUM5
    "IMAX=9000000
  
  OC1  = 0   ; Occasion flag
  OC2  = 0
  OC3  = 0
  OC4  = 0
   IF (OCC.EQ.1) OC1 = 1
   IF (OCC.EQ.2) OC2 = 1
   IF (OCC.EQ.3) OC3 = 1
   IF (OCC.EQ.4) OC4 = 1

; PK submodel
    CL    = CLI
    V2    = VCI
    V3    = VPI
    Q      = QI
    ALAG1 = ALAG
    D1    = DURI  ; Duration of zero-order absorption
    F1     = FI
    D2    = 0.5       ; Duration of infusions = 0.5 h
    F2     = 1
    KA   = KAI
    K23  = Q/V2
    K32  = Q/V3
    K      = CL/V2

; PD submodel placebo
    KOUT  = THETA(1)*EXP(ETA(3))      		     	; Elimination rate constant prolactin 
    BASE  = THETA(2)                                		         	; Base prolactin HV
       IF(PAT.EQ.1)      BASE = THETA(3)        	         	; Base prolactin Male patients 
       IF(SEX.EQ.1)      BASE = THETA(4)     	         	; Base prolactin Female patients
       IF(STU.EQ.101)  BASE = THETA(5)  		         	; Base prolactin Male patients Study 101
       IF(STU.EQ.101.AND.SEX.EQ.1) BASE=THETA(6)   	; Base prolactin Female pat Study 101
    OCBA  = OC1*ETA(6)+ OC2*ETA(7)+ OC3*ETA(8)+ OC4*ETA(9)    
    PRL0   = BASE*EXP(ETA(1)+OCBA)                            	; Baseline prolactin with IIV and IOV

    KINB   = KOUT*PRL0   	; Release rate of prolactin at baseline
    KDA    = THETA(7)         	; Turnover rate constant dopamine
    UPDA  = THETA(8)       	; Feedback factor     
    F4    =  PRL0                    	; Initialization of prolactin compartment
    F5    = 10000                   	; Initialization of dopamine compartment
    KINM  =  KINB*(1+F5)  	; Maximum release rate of prolactin

; Circadian submodel
    PI         = 3.141593
    DPHS  = THETA(13)				; Phase shift in patients
    AMP1  = THETA(9)*EXP(ETA(4))                        	; Amplitude of 1st cosine function
    PHS1   = THETA(10)+ DPHS *PAT                 	; Phase shift of 1st cosine
    AMP2  = THETA(11)                                              	; Amplitude of 2nd cosine function
    PHS2   = THETA(12)+ DPHS*PAT+ETA(5)  	; Phase shift of 2nd cosine
    
; PD submodel drug effect
    KI    = THETA(13)*EXP(ETA(2))   
 
$DES
    CP    = 1000*A(2)/V2    
    AAI   = 1        
        IF(A(5).GT.0) AAI = A(5)/(1+CP/KI+A(5)) 	; Dopamine-drug interaction 
    DIU1  = AMP1*COS(2*PI*(T-PHS1)/24)
    DIU2  = AMP2*COS(2*PI*(T-PHS2)/12)
    DIU   = DIU1 + DIU2
    KIN   = KINM*(1-AAI) + KINB*DIU            	; Prolactin release rate
    FEED  = 1
        IF(A(4).GT.0) FEED = (A(4)/PRL0)**UPDA  	; Feedback

    DADT(1) = -KA*A(1)                      
    DADT(2) =  KA *A(1) - (K23+K)*A(2) + K32*A(3)
    DADT(3) =  K23*A(2) - K32*A(3)
    DADT(4) =  KIN - KOUT*A(4) 
    DADT(5) =  KDA*F5*FEED - KDA*A(5)
    
$ERROR
    IPRED = 0
       IF(A(4).GT.0) IPRED = LOG(A(4))
    W     = THETA(14)
       IF(PAT.EQ.1) W = THETA(15)
       IF(SEX.EQ.1) W = THETA(16)
    IRES  = DV-IPRED
    IWRES = IRES/W 
    Y     = IPRED+ERR(1)*W

$THETA  
 (0,   .664)          	; 1  KOUT
 (0,   7.67)          	; 2  PRL0_in_Male_HV
 (0,   16.1)           	; 3  PRL0_in_Male_patients
 (0,   35.2)           	; 4  PRL0_PAT_women
 (0,   11.3)           	; 5  PRL0_in_Males_Study_101 
 (0,   23.2)           	; 6  PRL0_in_Females_Study_101
 (0,   .156)          	; 7  KDA
 (0,   1.44)          	; 8  UPDA 
 (-1,  .532, 1)      	; 9  AMP1
 (12,  20.1, 25)    	; 10 PHS1
 (-1, -.314, 1)     	; 11 AMP2
 (-2,  13.7,  17)   	; 12 PHS2
 (0,   1.96)         	; 13 KI
 (-5, -1.61)        	; 14 Phase_shift_in_Patients
 (0,   .290)         	; 15 Res_err_in_Male_HV
 (0,   .422)         	; 16 Res_err_in_Male_Patients
 (0,   .571)         	; 17 Res_err_in_Female_Patients
  
 $OMEGA BLOCK(2) 
     .425                  		; 1 PPV_PRL0 
     .757  1.82           		; 2 PPV_KI
 $OMEGA .589   			; 3 PPV_KOUT
 $OMEGA .0558 			; 4 PPV_AMP1
 $OMEGA 1.80   			; 5 PPV_PHS2
 $OMEGA BLOCK(1) 
 .0657  ; 6 IOV_in_PRL01 
 $OMEGA BLOCK(1) SAME
 ;; 7 IOV_in_PRL02
 $OMEGA BLOCK(1) SAME
 ;; 8 IOV_in_PRL03
 $OMEGA BLOCK(1) SAME  	
 ;; 9 IOV_in_PRL04

$SIGMA  1 FIX ; EPS1

$EST PRINT=5 MAX=9999 SIGDIG=3 METHOD=1 
$COV MATRIX = S
$TABLE ID TIME IPRED IWRES NOPRINT ONEHEADER FILE=sdtab1

