$PROBLEM CURRENT EXPRIMO HCV MODEL
$INPUT ID TIME AMT 
DVX=DROP ; virions 
DV ; log10 virions
RATE CMT MDV GENO AGE SEX RACE BW PEG RBV DRBV TEND CENS
;$REG PEG RBV T_End
$DATA Sim_mlx07.csv

$EST METHOD=SAEM NBURN=3000 NITER=1000 ISAMPLE=1 NSIG=2 SIGL=6
     CTYPE=3 CITER=10 CALPHA=0.05 GRD=TS(11) NOPRIOR=1
     LAPLACE NUMERICAL SLOW NOABORT PRINT=10
     FILE=005_myhcvmodel03_ppv4_A08_MU_SAEM_IMP_NM73F.raw
$EST METHOD=IMP EONLY=1 ISAMPLE=1000 NITER=5 MAPITER=0
$COV MATRIX=R PRINT=E UNCONDITIONAL SIGL=8

$SUBR ADVAN13 TOL=6

;$PSI RR0 p c delta ED50peg ED50rbv K r
$THETA
(0.1,6,)          ; POP_RR0 basic reproductive number
(0.1,20,)         ; POP_p   virion production rate IU.hepatocyte.day-1
(0.1,5,)          ; POP_c   virion elimination rate constant day-1
(0.001,0.25,)     ; POP_delta infected cell death rate constant day-1
(-1,-0.25,1)      ; BETA_delta GENO1 covariate effect on delta
(0.001,1,)        ; POP_ED50peg ED50 of peginterferon (HCVGN1) mcg.week-1
(-1,2,10)         ; BETA_ED50peg GENO1 covariate effect on ED50peg
(0.01,15,)        ; POP_ED50rbv ED50 of ribavirin mcg.kg-1.day-1
(0.001,0.03,0.2)  ; POP_K   antiviral-effect decay constant day-1
(0.000001,0.005,) ; POP_r   hepatocyte proliferation rate constant day-1

(0.001,0.6,)  ; RUV_SDVL residual error log10(IU.mL-1)

$OMEGA
1  ; PPV_RR0  1
0 FIX ; PPV_p
1  ; PPV_c 1
0.49 ; PPV_delta 0.49=0.7**2
2.25 ; PPV_ED50peg 2.25=1.5**2
0 FIX ; PPV_ED50rbv
0 FIX ; PPV_K
0 FIX ; PPV_r

$SIGMA 1 FIX ; EPS1

$MODEL
COMP = (TC)
COMP = (IC)
COMP = (VL_I)
COMP = (VL_NI)

$PK

IF (NEWIND.EQ.0) THEN
   ; some constants
   TCMAX  = 18500000                 ; cells.mL-1
   DTC    = 1/300                    ; day-1 target cell death rate constant
   ICMIN  = 1/13500                  ; cells.mL-1
   S      = TCMAX*DTC                ; cells.mL-1.day-1
   LLOQ   = 50                       ; IU.mL-1
   LN10   = LOG(10)
   L10LLOQ= LOG(LLOQ)/LN10           ; log10(LLOQ viral load IU.mL-1)
ENDIF

;Group variables

;Genotype effects
IF (GENO.NE.1) THEN
   BDELTA=0
   BED50PEG=0
ELSE ; GENO 1
   BDELTA=THETA(5)
   BED50PEG=THETA(7)
ENDIF

;MU reference log linearization
MU_1    =LOG(THETA(1))
MU_2      =LOG(THETA(2))
MU_3      =LOG(THETA(3))
MU_4  =LOG(THETA(4))   + BDELTA
MU_5=LOG(THETA(6)) + BED50PEG
MU_6=LOG(THETA(8))
MU_7      =LOG(THETA(9))
MU_8      =LOG(THETA(10))

;Individual variables
RR0    =EXP(MU_1     + ETA(1))
VPR    =EXP(MU_2       + ETA(2))
C      =EXP(MU_3       + ETA(3))
DELTA  =EXP(MU_4   + ETA(4))
ED50PEG=EXP(MU_5 + ETA(5))
ED50RBV=EXP(MU_6 + ETA(6))
K      =EXP(MU_7       + ETA(7))
R      =EXP(MU_8       + ETA(8))

; some variables
EPSPEG = PEG/(PEG+ED50PEG)
RHO    = RBV/(RBV+ED50RBV)

RR0T   = 1 + RR0

BETA   = RR0T*DELTA*C/(TCMAX*VPR)  ; VL IU.mL-1.day-1

; compute the initial values
E      = DELTA*RR0T/R
B      = DELTA*TCMAX/R
D      = (TCMAX + (DTC*B)/(DELTA*E) - B/E - B) / E

TC0    = 0.5*(-D + SQRT(D**2 + (4*TCMAX*S)/(R*(E**2))))
IC0    = TC0*(E-1) + TCMAX - B
VLI0   = VPR*IC0/C
VLNI0  = 0

; Set intital conditions
A_0(1) = TC0
A_0(2) = IC0
A_0(3) = VLI0
A_0(4) = VLNI0


$DES
TC=A(1)
IC=A(2)
VLI=A(3)
VLNI=A(4)
; condition on the number of infected cells
IF (IC.LT.ICMIN) THEN
  PCOND = 0
ELSE
  PCOND = VPR
ENDIF
; inhibition before and after the end of treatment
IF (T.GT.TEND) THEN
  COEFF = EXP(-K*(T-TEND))
ELSE
  COEFF = 1
ENDIF

RHOCOND = COEFF*RHO 
EPSCOND = COEFF*EPSPEG

; proliferation rate of the cells
R_PROLIF = R*(1-(TC+IC)/TCMAX)

DTTC   = S + R_PROLIF*TC - DTC*TC - BETA*TC*VLI
DTIC   = BETA*TC*VLI + R_PROLIF*IC - DELTA*IC
DTVLI  = (1-RHOCOND)*(1-EPSCOND)*PCOND*IC - C*VLI
DTVLNI = RHOCOND*(1-EPSCOND)*PCOND*IC - C*VLNI

; ODE system
DADT(1)   = DTTC  ; TC
DADT(2)   = DTIC   ; IC
DADT(3)   = DTVLI ; VLI
DADT(4)   = DTVLNI  ; VLNI

$ERROR
;E suffix because cannot use same variable names in $DES and $ERROR
TCE=A(1)
ICE=A(2)
VLIE=A(3)
VLNIE=A(4)

VL=VLIE + VLNIE

;OUTPUT1 = log10(max(VL_I+VL_NI, 1))
IF (VL.LT.1) VL=1
L10VL=LOG(VL)/LN10
IF (CENS.EQ.0) THEN ; non-censored VL
   F_FLAG=0
   Y=L10VL + THETA(11)*ERR(1) ; log10(IU.mL-1)
ELSE ; censored VL
   F_FLAG=1
   Y=PHI((L10LLOQ-L10VL)/THETA(11)) ; M3
;   CUMD=PHI((LLOQ-VL)/SDVL)
;   CUMDZ=PHI(-VL/SDVL)
;   Y=(CUMD-CUMDZ)/(1-CUMDZ) ; M4
ENDIF

$TABLE ID TIME PEG RBV
TCE ICE VLIE VLNIE
CENS VL Y MDV
ONEHEADER NOPRINT FILE=hcv.fit
